# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class User(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            id = schemas.IntSchema
            username = schemas.StrSchema
            email = schemas.StrSchema
            firstname = schemas.StrSchema
            lastname = schemas.StrSchema
            title = schemas.StrSchema
            department = schemas.StrSchema
            company = schemas.StrSchema
            comment = schemas.StrSchema
            group_id = schemas.IntSchema
            
            
            class role_ids(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.IntSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, decimal.Decimal, int, ]], typing.List[typing.Union[MetaOapg.items, decimal.Decimal, int, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'role_ids':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            phone = schemas.StrSchema
            
            
            class state(
                schemas.EnumBase,
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        0: "POSITIVE_0",
                        1: "POSITIVE_1",
                        2: "POSITIVE_2",
                        3: "POSITIVE_3",
                    }
                
                @schemas.classproperty
                def POSITIVE_0(cls):
                    return cls(0)
                
                @schemas.classproperty
                def POSITIVE_1(cls):
                    return cls(1)
                
                @schemas.classproperty
                def POSITIVE_2(cls):
                    return cls(2)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
            
            
            class status(
                schemas.EnumBase,
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        0: "POSITIVE_0",
                        1: "POSITIVE_1",
                        2: "POSITIVE_2",
                        3: "POSITIVE_3",
                        4: "POSITIVE_4",
                        5: "POSITIVE_5",
                        7: "POSITIVE_7",
                        8: "POSITIVE_8",
                    }
                
                @schemas.classproperty
                def POSITIVE_0(cls):
                    return cls(0)
                
                @schemas.classproperty
                def POSITIVE_1(cls):
                    return cls(1)
                
                @schemas.classproperty
                def POSITIVE_2(cls):
                    return cls(2)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
                
                @schemas.classproperty
                def POSITIVE_4(cls):
                    return cls(4)
                
                @schemas.classproperty
                def POSITIVE_5(cls):
                    return cls(5)
                
                @schemas.classproperty
                def POSITIVE_7(cls):
                    return cls(7)
                
                @schemas.classproperty
                def POSITIVE_8(cls):
                    return cls(8)
            directory_id = schemas.IntSchema
            trusted_idp_id = schemas.IntSchema
            manager_ad_id = schemas.StrSchema
            manager_user_id = schemas.StrSchema
            samaccountname = schemas.StrSchema
            member_of = schemas.StrSchema
            userprincipalname = schemas.StrSchema
            distinguished_name = schemas.StrSchema
            external_id = schemas.StrSchema
            activated_at = schemas.StrSchema
            last_login = schemas.StrSchema
            invitation_sent_at = schemas.StrSchema
            updated_at = schemas.StrSchema
            preferred_locale_code = schemas.StrSchema
            created_at = schemas.StrSchema
            invalid_login_attempts = schemas.IntSchema
            locked_until = schemas.StrSchema
            password_changed_at = schemas.StrSchema
            password = schemas.StrSchema
            password_confirmation = schemas.StrSchema
            password_algorithm = schemas.StrSchema
            salt = schemas.StrSchema
            __annotations__ = {
                "id": id,
                "username": username,
                "email": email,
                "firstname": firstname,
                "lastname": lastname,
                "title": title,
                "department": department,
                "company": company,
                "comment": comment,
                "group_id": group_id,
                "role_ids": role_ids,
                "phone": phone,
                "state": state,
                "status": status,
                "directory_id": directory_id,
                "trusted_idp_id": trusted_idp_id,
                "manager_ad_id": manager_ad_id,
                "manager_user_id": manager_user_id,
                "samaccountname": samaccountname,
                "member_of": member_of,
                "userprincipalname": userprincipalname,
                "distinguished_name": distinguished_name,
                "external_id": external_id,
                "activated_at": activated_at,
                "last_login": last_login,
                "invitation_sent_at": invitation_sent_at,
                "updated_at": updated_at,
                "preferred_locale_code": preferred_locale_code,
                "created_at": created_at,
                "invalid_login_attempts": invalid_login_attempts,
                "locked_until": locked_until,
                "password_changed_at": password_changed_at,
                "password": password,
                "password_confirmation": password_confirmation,
                "password_algorithm": password_algorithm,
                "salt": salt,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["username"]) -> MetaOapg.properties.username: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["email"]) -> MetaOapg.properties.email: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["firstname"]) -> MetaOapg.properties.firstname: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["lastname"]) -> MetaOapg.properties.lastname: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["department"]) -> MetaOapg.properties.department: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["company"]) -> MetaOapg.properties.company: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["comment"]) -> MetaOapg.properties.comment: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["group_id"]) -> MetaOapg.properties.group_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["role_ids"]) -> MetaOapg.properties.role_ids: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["phone"]) -> MetaOapg.properties.phone: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["state"]) -> MetaOapg.properties.state: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["directory_id"]) -> MetaOapg.properties.directory_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trusted_idp_id"]) -> MetaOapg.properties.trusted_idp_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["manager_ad_id"]) -> MetaOapg.properties.manager_ad_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["manager_user_id"]) -> MetaOapg.properties.manager_user_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["samaccountname"]) -> MetaOapg.properties.samaccountname: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["member_of"]) -> MetaOapg.properties.member_of: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["userprincipalname"]) -> MetaOapg.properties.userprincipalname: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["distinguished_name"]) -> MetaOapg.properties.distinguished_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["external_id"]) -> MetaOapg.properties.external_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["activated_at"]) -> MetaOapg.properties.activated_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_login"]) -> MetaOapg.properties.last_login: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["invitation_sent_at"]) -> MetaOapg.properties.invitation_sent_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["preferred_locale_code"]) -> MetaOapg.properties.preferred_locale_code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["invalid_login_attempts"]) -> MetaOapg.properties.invalid_login_attempts: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["locked_until"]) -> MetaOapg.properties.locked_until: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["password_changed_at"]) -> MetaOapg.properties.password_changed_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["password"]) -> MetaOapg.properties.password: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["password_confirmation"]) -> MetaOapg.properties.password_confirmation: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["password_algorithm"]) -> MetaOapg.properties.password_algorithm: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["salt"]) -> MetaOapg.properties.salt: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "username", "email", "firstname", "lastname", "title", "department", "company", "comment", "group_id", "role_ids", "phone", "state", "status", "directory_id", "trusted_idp_id", "manager_ad_id", "manager_user_id", "samaccountname", "member_of", "userprincipalname", "distinguished_name", "external_id", "activated_at", "last_login", "invitation_sent_at", "updated_at", "preferred_locale_code", "created_at", "invalid_login_attempts", "locked_until", "password_changed_at", "password", "password_confirmation", "password_algorithm", "salt", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["username"]) -> typing.Union[MetaOapg.properties.username, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["email"]) -> typing.Union[MetaOapg.properties.email, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["firstname"]) -> typing.Union[MetaOapg.properties.firstname, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["lastname"]) -> typing.Union[MetaOapg.properties.lastname, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["title"]) -> typing.Union[MetaOapg.properties.title, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["department"]) -> typing.Union[MetaOapg.properties.department, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["company"]) -> typing.Union[MetaOapg.properties.company, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["comment"]) -> typing.Union[MetaOapg.properties.comment, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["group_id"]) -> typing.Union[MetaOapg.properties.group_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["role_ids"]) -> typing.Union[MetaOapg.properties.role_ids, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["phone"]) -> typing.Union[MetaOapg.properties.phone, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["state"]) -> typing.Union[MetaOapg.properties.state, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union[MetaOapg.properties.status, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["directory_id"]) -> typing.Union[MetaOapg.properties.directory_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trusted_idp_id"]) -> typing.Union[MetaOapg.properties.trusted_idp_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["manager_ad_id"]) -> typing.Union[MetaOapg.properties.manager_ad_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["manager_user_id"]) -> typing.Union[MetaOapg.properties.manager_user_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["samaccountname"]) -> typing.Union[MetaOapg.properties.samaccountname, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["member_of"]) -> typing.Union[MetaOapg.properties.member_of, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["userprincipalname"]) -> typing.Union[MetaOapg.properties.userprincipalname, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["distinguished_name"]) -> typing.Union[MetaOapg.properties.distinguished_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["external_id"]) -> typing.Union[MetaOapg.properties.external_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["activated_at"]) -> typing.Union[MetaOapg.properties.activated_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_login"]) -> typing.Union[MetaOapg.properties.last_login, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["invitation_sent_at"]) -> typing.Union[MetaOapg.properties.invitation_sent_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> typing.Union[MetaOapg.properties.updated_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["preferred_locale_code"]) -> typing.Union[MetaOapg.properties.preferred_locale_code, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["invalid_login_attempts"]) -> typing.Union[MetaOapg.properties.invalid_login_attempts, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["locked_until"]) -> typing.Union[MetaOapg.properties.locked_until, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["password_changed_at"]) -> typing.Union[MetaOapg.properties.password_changed_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["password"]) -> typing.Union[MetaOapg.properties.password, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["password_confirmation"]) -> typing.Union[MetaOapg.properties.password_confirmation, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["password_algorithm"]) -> typing.Union[MetaOapg.properties.password_algorithm, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["salt"]) -> typing.Union[MetaOapg.properties.salt, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "username", "email", "firstname", "lastname", "title", "department", "company", "comment", "group_id", "role_ids", "phone", "state", "status", "directory_id", "trusted_idp_id", "manager_ad_id", "manager_user_id", "samaccountname", "member_of", "userprincipalname", "distinguished_name", "external_id", "activated_at", "last_login", "invitation_sent_at", "updated_at", "preferred_locale_code", "created_at", "invalid_login_attempts", "locked_until", "password_changed_at", "password", "password_confirmation", "password_algorithm", "salt", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        username: typing.Union[MetaOapg.properties.username, str, schemas.Unset] = schemas.unset,
        email: typing.Union[MetaOapg.properties.email, str, schemas.Unset] = schemas.unset,
        firstname: typing.Union[MetaOapg.properties.firstname, str, schemas.Unset] = schemas.unset,
        lastname: typing.Union[MetaOapg.properties.lastname, str, schemas.Unset] = schemas.unset,
        title: typing.Union[MetaOapg.properties.title, str, schemas.Unset] = schemas.unset,
        department: typing.Union[MetaOapg.properties.department, str, schemas.Unset] = schemas.unset,
        company: typing.Union[MetaOapg.properties.company, str, schemas.Unset] = schemas.unset,
        comment: typing.Union[MetaOapg.properties.comment, str, schemas.Unset] = schemas.unset,
        group_id: typing.Union[MetaOapg.properties.group_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        role_ids: typing.Union[MetaOapg.properties.role_ids, list, tuple, schemas.Unset] = schemas.unset,
        phone: typing.Union[MetaOapg.properties.phone, str, schemas.Unset] = schemas.unset,
        state: typing.Union[MetaOapg.properties.state, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        status: typing.Union[MetaOapg.properties.status, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        directory_id: typing.Union[MetaOapg.properties.directory_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        trusted_idp_id: typing.Union[MetaOapg.properties.trusted_idp_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        manager_ad_id: typing.Union[MetaOapg.properties.manager_ad_id, str, schemas.Unset] = schemas.unset,
        manager_user_id: typing.Union[MetaOapg.properties.manager_user_id, str, schemas.Unset] = schemas.unset,
        samaccountname: typing.Union[MetaOapg.properties.samaccountname, str, schemas.Unset] = schemas.unset,
        member_of: typing.Union[MetaOapg.properties.member_of, str, schemas.Unset] = schemas.unset,
        userprincipalname: typing.Union[MetaOapg.properties.userprincipalname, str, schemas.Unset] = schemas.unset,
        distinguished_name: typing.Union[MetaOapg.properties.distinguished_name, str, schemas.Unset] = schemas.unset,
        external_id: typing.Union[MetaOapg.properties.external_id, str, schemas.Unset] = schemas.unset,
        activated_at: typing.Union[MetaOapg.properties.activated_at, str, schemas.Unset] = schemas.unset,
        last_login: typing.Union[MetaOapg.properties.last_login, str, schemas.Unset] = schemas.unset,
        invitation_sent_at: typing.Union[MetaOapg.properties.invitation_sent_at, str, schemas.Unset] = schemas.unset,
        updated_at: typing.Union[MetaOapg.properties.updated_at, str, schemas.Unset] = schemas.unset,
        preferred_locale_code: typing.Union[MetaOapg.properties.preferred_locale_code, str, schemas.Unset] = schemas.unset,
        created_at: typing.Union[MetaOapg.properties.created_at, str, schemas.Unset] = schemas.unset,
        invalid_login_attempts: typing.Union[MetaOapg.properties.invalid_login_attempts, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        locked_until: typing.Union[MetaOapg.properties.locked_until, str, schemas.Unset] = schemas.unset,
        password_changed_at: typing.Union[MetaOapg.properties.password_changed_at, str, schemas.Unset] = schemas.unset,
        password: typing.Union[MetaOapg.properties.password, str, schemas.Unset] = schemas.unset,
        password_confirmation: typing.Union[MetaOapg.properties.password_confirmation, str, schemas.Unset] = schemas.unset,
        password_algorithm: typing.Union[MetaOapg.properties.password_algorithm, str, schemas.Unset] = schemas.unset,
        salt: typing.Union[MetaOapg.properties.salt, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'User':
        return super().__new__(
            cls,
            *_args,
            id=id,
            username=username,
            email=email,
            firstname=firstname,
            lastname=lastname,
            title=title,
            department=department,
            company=company,
            comment=comment,
            group_id=group_id,
            role_ids=role_ids,
            phone=phone,
            state=state,
            status=status,
            directory_id=directory_id,
            trusted_idp_id=trusted_idp_id,
            manager_ad_id=manager_ad_id,
            manager_user_id=manager_user_id,
            samaccountname=samaccountname,
            member_of=member_of,
            userprincipalname=userprincipalname,
            distinguished_name=distinguished_name,
            external_id=external_id,
            activated_at=activated_at,
            last_login=last_login,
            invitation_sent_at=invitation_sent_at,
            updated_at=updated_at,
            preferred_locale_code=preferred_locale_code,
            created_at=created_at,
            invalid_login_attempts=invalid_login_attempts,
            locked_until=locked_until,
            password_changed_at=password_changed_at,
            password=password,
            password_confirmation=password_confirmation,
            password_algorithm=password_algorithm,
            salt=salt,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_1_groups_group_id.get import GetGroupById
from onelogin.paths.api_1_groups.get import GetGroups


class GroupsApi(
    GetGroupById,
    GetGroups,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from onelogin.paths.api_2_branding_brands_brand_id_templates_template_type_locale.get import ApiForget
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_type_locale.put import ApiForput


class Api2BrandingBrandsBrandIdTemplatesTemplateTypeLocale(
    ApiForget,
    ApiForput,
):
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_mappings.post import CreateMapping
from onelogin.paths.api_2_mappings_mapping_id.delete import DeleteMapping
from onelogin.paths.api_2_mappings_mapping_id.get import GetMapping
from onelogin.paths.api_2_mappings_actions_mapping_action_value_values.get import ListMappingActionValues
from onelogin.paths.api_2_mappings_conditions.get import ListMappingConditions
from onelogin.paths.api_2_mappings_conditions_mapping_condition_value_operators.get import ListMappingConditionsOperators
from onelogin.paths.api_2_mappings_conditions_mapping_condition_value_values.get import ListMappingContionValues
from onelogin.paths.api_2_mappings.get import ListMappings
from onelogin.paths.api_2_mappings_actions.get import ListMappingsActions
from onelogin.paths.api_2_mappings_sort.put import SortMappings
from onelogin.paths.api_2_mappings_mapping_id.put import UpdateMapping


class UserMappingsApi(
    CreateMapping,
    DeleteMapping,
    GetMapping,
    ListMappingActionValues,
    ListMappingConditions,
    ListMappingConditionsOperators,
    ListMappingContionValues,
    ListMappings,
    ListMappingsActions,
    SortMappings,
    UpdateMapping,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class Event(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            account_id = schemas.IntSchema
            actor_system = schemas.StrSchema
            actor_user_id = schemas.IntSchema
            actor_user_name = schemas.StrSchema
            adc_id = schemas.IntSchema
            app_name = schemas.StrSchema
            app_id = schemas.IntSchema
            assumed_by_superadmin_or_reseller = schemas.IntSchema
            assuming_acting_user_id = schemas.IntSchema
            certificate_id = schemas.IntSchema
            client_id = schemas.StrSchema
            created_at = schemas.StrSchema
            custom_message = schemas.StrSchema
            directory_sync_run_id = schemas.IntSchema
            error_description = schemas.StrSchema
            
            
            class event_type_id(
                schemas.EnumBase,
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        1: "POSITIVE_1",
                        2: "POSITIVE_2",
                        3: "POSITIVE_3",
                        4: "POSITIVE_4",
                        5: "POSITIVE_5",
                        6: "POSITIVE_6",
                        7: "POSITIVE_7",
                        8: "POSITIVE_8",
                        9: "POSITIVE_9",
                        10: "POSITIVE_10",
                        11: "POSITIVE_11",
                        12: "POSITIVE_12",
                        13: "POSITIVE_13",
                        14: "POSITIVE_14",
                        15: "POSITIVE_15",
                        16: "POSITIVE_16",
                        17: "POSITIVE_17",
                        18: "POSITIVE_18",
                        19: "POSITIVE_19",
                        20: "POSITIVE_20",
                        21: "POSITIVE_21",
                        22: "POSITIVE_22",
                        23: "POSITIVE_23",
                        24: "POSITIVE_24",
                        25: "POSITIVE_25",
                        26: "POSITIVE_26",
                        27: "POSITIVE_27",
                        28: "POSITIVE_28",
                        29: "POSITIVE_29",
                        30: "POSITIVE_30",
                        31: "POSITIVE_31",
                        32: "POSITIVE_32",
                        33: "POSITIVE_33",
                        34: "POSITIVE_34",
                        35: "POSITIVE_35",
                        36: "POSITIVE_36",
                        37: "POSITIVE_37",
                        38: "POSITIVE_38",
                        39: "POSITIVE_39",
                        40: "POSITIVE_40",
                        41: "POSITIVE_41",
                        42: "POSITIVE_42",
                        43: "POSITIVE_43",
                        44: "POSITIVE_44",
                        45: "POSITIVE_45",
                        46: "POSITIVE_46",
                        47: "POSITIVE_47",
                        48: "POSITIVE_48",
                        49: "POSITIVE_49",
                        50: "POSITIVE_50",
                        51: "POSITIVE_51",
                        52: "POSITIVE_52",
                        53: "POSITIVE_53",
                        54: "POSITIVE_54",
                        55: "POSITIVE_55",
                        56: "POSITIVE_56",
                        57: "POSITIVE_57",
                        58: "POSITIVE_58",
                        59: "POSITIVE_59",
                        60: "POSITIVE_60",
                        61: "POSITIVE_61",
                        62: "POSITIVE_62",
                        63: "POSITIVE_63",
                        64: "POSITIVE_64",
                        65: "POSITIVE_65",
                        66: "POSITIVE_66",
                        67: "POSITIVE_67",
                        68: "POSITIVE_68",
                        69: "POSITIVE_69",
                        70: "POSITIVE_70",
                        71: "POSITIVE_71",
                        72: "POSITIVE_72",
                        73: "POSITIVE_73",
                        74: "POSITIVE_74",
                        75: "POSITIVE_75",
                        76: "POSITIVE_76",
                        77: "POSITIVE_77",
                        78: "POSITIVE_78",
                        79: "POSITIVE_79",
                        80: "POSITIVE_80",
                        81: "POSITIVE_81",
                        82: "POSITIVE_82",
                        83: "POSITIVE_83",
                        84: "POSITIVE_84",
                        85: "POSITIVE_85",
                        86: "POSITIVE_86",
                        87: "POSITIVE_87",
                        88: "POSITIVE_88",
                        89: "POSITIVE_89",
                        90: "POSITIVE_90",
                        91: "POSITIVE_91",
                        92: "POSITIVE_92",
                        95: "POSITIVE_95",
                        96: "POSITIVE_96",
                        100: "POSITIVE_100",
                        101: "POSITIVE_101",
                        102: "POSITIVE_102",
                        103: "POSITIVE_103",
                        104: "POSITIVE_104",
                        105: "POSITIVE_105",
                        106: "POSITIVE_106",
                        110: "POSITIVE_110",
                        111: "POSITIVE_111",
                        112: "POSITIVE_112",
                        113: "POSITIVE_113",
                        114: "POSITIVE_114",
                        115: "POSITIVE_115",
                        116: "POSITIVE_116",
                        117: "POSITIVE_117",
                        118: "POSITIVE_118",
                        119: "POSITIVE_119",
                        120: "POSITIVE_120",
                        121: "POSITIVE_121",
                        122: "POSITIVE_122",
                        123: "POSITIVE_123",
                        124: "POSITIVE_124",
                        125: "POSITIVE_125",
                        126: "POSITIVE_126",
                        127: "POSITIVE_127",
                        128: "POSITIVE_128",
                        129: "POSITIVE_129",
                        130: "POSITIVE_130",
                        131: "POSITIVE_131",
                        132: "POSITIVE_132",
                        133: "POSITIVE_133",
                        134: "POSITIVE_134",
                        135: "POSITIVE_135",
                        136: "POSITIVE_136",
                        137: "POSITIVE_137",
                        138: "POSITIVE_138",
                        139: "POSITIVE_139",
                        140: "POSITIVE_140",
                        141: "POSITIVE_141",
                        145: "POSITIVE_145",
                        146: "POSITIVE_146",
                        147: "POSITIVE_147",
                        148: "POSITIVE_148",
                        149: "POSITIVE_149",
                        150: "POSITIVE_150",
                        151: "POSITIVE_151",
                        152: "POSITIVE_152",
                        153: "POSITIVE_153",
                        154: "POSITIVE_154",
                        155: "POSITIVE_155",
                        156: "POSITIVE_156",
                        157: "POSITIVE_157",
                        158: "POSITIVE_158",
                        159: "POSITIVE_159",
                        160: "POSITIVE_160",
                        161: "POSITIVE_161",
                        162: "POSITIVE_162",
                        163: "POSITIVE_163",
                        164: "POSITIVE_164",
                        165: "POSITIVE_165",
                        166: "POSITIVE_166",
                        167: "POSITIVE_167",
                        168: "POSITIVE_168",
                        169: "POSITIVE_169",
                        170: "POSITIVE_170",
                        171: "POSITIVE_171",
                        172: "POSITIVE_172",
                        173: "POSITIVE_173",
                        174: "POSITIVE_174",
                        175: "POSITIVE_175",
                        176: "POSITIVE_176",
                        177: "POSITIVE_177",
                        178: "POSITIVE_178",
                        179: "POSITIVE_179",
                        180: "POSITIVE_180",
                        181: "POSITIVE_181",
                        182: "POSITIVE_182",
                        183: "POSITIVE_183",
                        184: "POSITIVE_184",
                        185: "POSITIVE_185",
                        186: "POSITIVE_186",
                        187: "POSITIVE_187",
                        188: "POSITIVE_188",
                        189: "POSITIVE_189",
                        190: "POSITIVE_190",
                        191: "POSITIVE_191",
                        192: "POSITIVE_192",
                        193: "POSITIVE_193",
                        194: "POSITIVE_194",
                        195: "POSITIVE_195",
                        196: "POSITIVE_196",
                        197: "POSITIVE_197",
                        198: "POSITIVE_198",
                        199: "POSITIVE_199",
                        200: "POSITIVE_200",
                        201: "POSITIVE_201",
                        202: "POSITIVE_202",
                        203: "POSITIVE_203",
                        204: "POSITIVE_204",
                        205: "POSITIVE_205",
                        206: "POSITIVE_206",
                        207: "POSITIVE_207",
                        208: "POSITIVE_208",
                        209: "POSITIVE_209",
                        210: "POSITIVE_210",
                        211: "POSITIVE_211",
                        212: "POSITIVE_212",
                        213: "POSITIVE_213",
                        214: "POSITIVE_214",
                        215: "POSITIVE_215",
                        216: "POSITIVE_216",
                        217: "POSITIVE_217",
                        218: "POSITIVE_218",
                        219: "POSITIVE_219",
                        220: "POSITIVE_220",
                        221: "POSITIVE_221",
                        222: "POSITIVE_222",
                        223: "POSITIVE_223",
                        224: "POSITIVE_224",
                        225: "POSITIVE_225",
                        226: "POSITIVE_226",
                        227: "POSITIVE_227",
                        228: "POSITIVE_228",
                        229: "POSITIVE_229",
                        230: "POSITIVE_230",
                        231: "POSITIVE_231",
                        232: "POSITIVE_232",
                        233: "POSITIVE_233",
                        234: "POSITIVE_234",
                        235: "POSITIVE_235",
                        236: "POSITIVE_236",
                        237: "POSITIVE_237",
                        238: "POSITIVE_238",
                        239: "POSITIVE_239",
                        240: "POSITIVE_240",
                        241: "POSITIVE_241",
                        242: "POSITIVE_242",
                        243: "POSITIVE_243",
                        244: "POSITIVE_244",
                        245: "POSITIVE_245",
                        246: "POSITIVE_246",
                        247: "POSITIVE_247",
                        248: "POSITIVE_248",
                        249: "POSITIVE_249",
                        250: "POSITIVE_250",
                        251: "POSITIVE_251",
                        252: "POSITIVE_252",
                        253: "POSITIVE_253",
                        254: "POSITIVE_254",
                        255: "POSITIVE_255",
                        291: "POSITIVE_291",
                        300: "POSITIVE_300",
                        301: "POSITIVE_301",
                        303: "POSITIVE_303",
                        304: "POSITIVE_304",
                        305: "POSITIVE_305",
                        306: "POSITIVE_306",
                        307: "POSITIVE_307",
                        330: "POSITIVE_330",
                        331: "POSITIVE_331",
                        332: "POSITIVE_332",
                        333: "POSITIVE_333",
                        334: "POSITIVE_334",
                        400: "POSITIVE_400",
                        401: "POSITIVE_401",
                        402: "POSITIVE_402",
                        410: "POSITIVE_410",
                        411: "POSITIVE_411",
                        412: "POSITIVE_412",
                        501: "POSITIVE_501",
                        502: "POSITIVE_502",
                        503: "POSITIVE_503",
                        510: "POSITIVE_510",
                        511: "POSITIVE_511",
                        512: "POSITIVE_512",
                        513: "POSITIVE_513",
                        514: "POSITIVE_514",
                        515: "POSITIVE_515",
                        516: "POSITIVE_516",
                        517: "POSITIVE_517",
                        518: "POSITIVE_518",
                        519: "POSITIVE_519",
                        520: "POSITIVE_520",
                        521: "POSITIVE_521",
                        522: "POSITIVE_522",
                        523: "POSITIVE_523",
                        524: "POSITIVE_524",
                        525: "POSITIVE_525",
                        526: "POSITIVE_526",
                        527: "POSITIVE_527",
                        528: "POSITIVE_528",
                        529: "POSITIVE_529",
                        530: "POSITIVE_530",
                        531: "POSITIVE_531",
                        532: "POSITIVE_532",
                        533: "POSITIVE_533",
                        534: "POSITIVE_534",
                        535: "POSITIVE_535",
                        536: "POSITIVE_536",
                        537: "POSITIVE_537",
                        538: "POSITIVE_538",
                        539: "POSITIVE_539",
                        540: "POSITIVE_540",
                        541: "POSITIVE_541",
                        542: "POSITIVE_542",
                        545: "POSITIVE_545",
                        546: "POSITIVE_546",
                        550: "POSITIVE_550",
                        551: "POSITIVE_551",
                        552: "POSITIVE_552",
                        553: "POSITIVE_553",
                        554: "POSITIVE_554",
                        555: "POSITIVE_555",
                        600: "POSITIVE_600",
                        601: "POSITIVE_601",
                        602: "POSITIVE_602",
                        700: "POSITIVE_700",
                        701: "POSITIVE_701",
                        702: "POSITIVE_702",
                        703: "POSITIVE_703",
                        704: "POSITIVE_704",
                        705: "POSITIVE_705",
                        706: "POSITIVE_706",
                        800: "POSITIVE_800",
                        801: "POSITIVE_801",
                        802: "POSITIVE_802",
                        803: "POSITIVE_803",
                        804: "POSITIVE_804",
                        805: "POSITIVE_805",
                        900: "POSITIVE_900",
                        901: "POSITIVE_901",
                        902: "POSITIVE_902",
                        903: "POSITIVE_903",
                        904: "POSITIVE_904",
                        905: "POSITIVE_905",
                        906: "POSITIVE_906",
                        907: "POSITIVE_907",
                        911: "POSITIVE_911",
                        912: "POSITIVE_912",
                        931: "POSITIVE_931",
                        932: "POSITIVE_932",
                        950: "POSITIVE_950",
                        1001: "POSITIVE_1001",
                        1002: "POSITIVE_1002",
                        1010: "POSITIVE_1010",
                        1100: "POSITIVE_1100",
                        1101: "POSITIVE_1101",
                        1200: "POSITIVE_1200",
                        1201: "POSITIVE_1201",
                        1244: "POSITIVE_1244",
                        1245: "POSITIVE_1245",
                        1300: "POSITIVE_1300",
                        1301: "POSITIVE_1301",
                        1302: "POSITIVE_1302",
                        1303: "POSITIVE_1303",
                        1304: "POSITIVE_1304",
                        1305: "POSITIVE_1305",
                        1400: "POSITIVE_1400",
                        1401: "POSITIVE_1401",
                        1402: "POSITIVE_1402",
                        1403: "POSITIVE_1403",
                        1404: "POSITIVE_1404",
                        1405: "POSITIVE_1405",
                        1406: "POSITIVE_1406",
                        1407: "POSITIVE_1407",
                        1408: "POSITIVE_1408",
                        1409: "POSITIVE_1409",
                        1410: "POSITIVE_1410",
                        1411: "POSITIVE_1411",
                        1412: "POSITIVE_1412",
                        1413: "POSITIVE_1413",
                        1414: "POSITIVE_1414",
                        1415: "POSITIVE_1415",
                        1416: "POSITIVE_1416",
                        1417: "POSITIVE_1417",
                        1418: "POSITIVE_1418",
                        1419: "POSITIVE_1419",
                        1420: "POSITIVE_1420",
                        1421: "POSITIVE_1421",
                        1422: "POSITIVE_1422",
                        1423: "POSITIVE_1423",
                        1424: "POSITIVE_1424",
                        1500: "POSITIVE_1500",
                        1501: "POSITIVE_1501",
                        1502: "POSITIVE_1502",
                        1503: "POSITIVE_1503",
                        1504: "POSITIVE_1504",
                        1505: "POSITIVE_1505",
                        1506: "POSITIVE_1506",
                        1507: "POSITIVE_1507",
                        1508: "POSITIVE_1508",
                        1509: "POSITIVE_1509",
                        1510: "POSITIVE_1510",
                        1511: "POSITIVE_1511",
                        1512: "POSITIVE_1512",
                        1513: "POSITIVE_1513",
                        1514: "POSITIVE_1514",
                        1600: "POSITIVE_1600",
                        1601: "POSITIVE_1601",
                        1602: "POSITIVE_1602",
                        1603: "POSITIVE_1603",
                        1604: "POSITIVE_1604",
                        1605: "POSITIVE_1605",
                        1606: "POSITIVE_1606",
                        1607: "POSITIVE_1607",
                        1608: "POSITIVE_1608",
                        1609: "POSITIVE_1609",
                        1700: "POSITIVE_1700",
                        1701: "POSITIVE_1701",
                        1702: "POSITIVE_1702",
                        1801: "POSITIVE_1801",
                        1802: "POSITIVE_1802",
                        1900: "POSITIVE_1900",
                        1901: "POSITIVE_1901",
                        1902: "POSITIVE_1902",
                        1903: "POSITIVE_1903",
                        1904: "POSITIVE_1904",
                        1905: "POSITIVE_1905",
                        2000: "POSITIVE_2000",
                        2001: "POSITIVE_2001",
                        2002: "POSITIVE_2002",
                        2003: "POSITIVE_2003",
                        2004: "POSITIVE_2004",
                        2005: "POSITIVE_2005",
                        2006: "POSITIVE_2006",
                        2007: "POSITIVE_2007",
                        2008: "POSITIVE_2008",
                        2009: "POSITIVE_2009",
                        2010: "POSITIVE_2010",
                        2011: "POSITIVE_2011",
                        2012: "POSITIVE_2012",
                        2013: "POSITIVE_2013",
                        2014: "POSITIVE_2014",
                        2015: "POSITIVE_2015",
                        2016: "POSITIVE_2016",
                        2017: "POSITIVE_2017",
                        2018: "POSITIVE_2018",
                        2100: "POSITIVE_2100",
                        2101: "POSITIVE_2101",
                        2102: "POSITIVE_2102",
                        2103: "POSITIVE_2103",
                        2104: "POSITIVE_2104",
                        2105: "POSITIVE_2105",
                        2106: "POSITIVE_2106",
                        2107: "POSITIVE_2107",
                        2108: "POSITIVE_2108",
                        2109: "POSITIVE_2109",
                        2110: "POSITIVE_2110",
                        2111: "POSITIVE_2111",
                        2112: "POSITIVE_2112",
                        2113: "POSITIVE_2113",
                        2114: "POSITIVE_2114",
                        2201: "POSITIVE_2201",
                        2202: "POSITIVE_2202",
                        2203: "POSITIVE_2203",
                        2204: "POSITIVE_2204",
                        3000: "POSITIVE_3000",
                        3001: "POSITIVE_3001",
                        3002: "POSITIVE_3002",
                        3003: "POSITIVE_3003",
                        3004: "POSITIVE_3004",
                        3005: "POSITIVE_3005",
                        3006: "POSITIVE_3006",
                        3007: "POSITIVE_3007",
                        3008: "POSITIVE_3008",
                        3009: "POSITIVE_3009",
                        3010: "POSITIVE_3010",
                        3011: "POSITIVE_3011",
                        3012: "POSITIVE_3012",
                        3013: "POSITIVE_3013",
                        3014: "POSITIVE_3014",
                        3015: "POSITIVE_3015",
                        3016: "POSITIVE_3016",
                        3017: "POSITIVE_3017",
                        3018: "POSITIVE_3018",
                        3019: "POSITIVE_3019",
                        3020: "POSITIVE_3020",
                        3021: "POSITIVE_3021",
                        3022: "POSITIVE_3022",
                        3023: "POSITIVE_3023",
                        3024: "POSITIVE_3024",
                        3025: "POSITIVE_3025",
                        3026: "POSITIVE_3026",
                        3027: "POSITIVE_3027",
                        3028: "POSITIVE_3028",
                        9000: "POSITIVE_9000",
                        9001: "POSITIVE_9001",
                        9002: "POSITIVE_9002",
                        9003: "POSITIVE_9003",
                        9004: "POSITIVE_9004",
                        9005: "POSITIVE_9005",
                        9006: "POSITIVE_9006",
                        9007: "POSITIVE_9007",
                        9008: "POSITIVE_9008",
                        9009: "POSITIVE_9009",
                        9010: "POSITIVE_9010",
                        9011: "POSITIVE_9011",
                        9012: "POSITIVE_9012",
                        9013: "POSITIVE_9013",
                        9014: "POSITIVE_9014",
                        9015: "POSITIVE_9015",
                        9016: "POSITIVE_9016",
                        9017: "POSITIVE_9017",
                        9018: "POSITIVE_9018",
                        9019: "POSITIVE_9019",
                        9020: "POSITIVE_9020",
                        9021: "POSITIVE_9021",
                        9022: "POSITIVE_9022",
                        9023: "POSITIVE_9023",
                        9024: "POSITIVE_9024",
                        9025: "POSITIVE_9025",
                        9026: "POSITIVE_9026",
                        9027: "POSITIVE_9027",
                        9028: "POSITIVE_9028",
                        9029: "POSITIVE_9029",
                        9030: "POSITIVE_9030",
                        9031: "POSITIVE_9031",
                        9032: "POSITIVE_9032",
                        9033: "POSITIVE_9033",
                        9034: "POSITIVE_9034",
                        9035: "POSITIVE_9035",
                        9036: "POSITIVE_9036",
                        9037: "POSITIVE_9037",
                        9038: "POSITIVE_9038",
                        9039: "POSITIVE_9039",
                        9040: "POSITIVE_9040",
                        9041: "POSITIVE_9041",
                        9042: "POSITIVE_9042",
                        9043: "POSITIVE_9043",
                        9044: "POSITIVE_9044",
                        9045: "POSITIVE_9045",
                        9046: "POSITIVE_9046",
                        9047: "POSITIVE_9047",
                        9048: "POSITIVE_9048",
                        9049: "POSITIVE_9049",
                        9050: "POSITIVE_9050",
                        9051: "POSITIVE_9051",
                        9052: "POSITIVE_9052",
                        9053: "POSITIVE_9053",
                        9054: "POSITIVE_9054",
                        9055: "POSITIVE_9055",
                        9056: "POSITIVE_9056",
                        9057: "POSITIVE_9057",
                        9058: "POSITIVE_9058",
                        9059: "POSITIVE_9059",
                    }
                
                @schemas.classproperty
                def POSITIVE_1(cls):
                    return cls(1)
                
                @schemas.classproperty
                def POSITIVE_2(cls):
                    return cls(2)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
                
                @schemas.classproperty
                def POSITIVE_4(cls):
                    return cls(4)
                
                @schemas.classproperty
                def POSITIVE_5(cls):
                    return cls(5)
                
                @schemas.classproperty
                def POSITIVE_6(cls):
                    return cls(6)
                
                @schemas.classproperty
                def POSITIVE_7(cls):
                    return cls(7)
                
                @schemas.classproperty
                def POSITIVE_8(cls):
                    return cls(8)
                
                @schemas.classproperty
                def POSITIVE_9(cls):
                    return cls(9)
                
                @schemas.classproperty
                def POSITIVE_10(cls):
                    return cls(10)
                
                @schemas.classproperty
                def POSITIVE_11(cls):
                    return cls(11)
                
                @schemas.classproperty
                def POSITIVE_12(cls):
                    return cls(12)
                
                @schemas.classproperty
                def POSITIVE_13(cls):
                    return cls(13)
                
                @schemas.classproperty
                def POSITIVE_14(cls):
                    return cls(14)
                
                @schemas.classproperty
                def POSITIVE_15(cls):
                    return cls(15)
                
                @schemas.classproperty
                def POSITIVE_16(cls):
                    return cls(16)
                
                @schemas.classproperty
                def POSITIVE_17(cls):
                    return cls(17)
                
                @schemas.classproperty
                def POSITIVE_18(cls):
                    return cls(18)
                
                @schemas.classproperty
                def POSITIVE_19(cls):
                    return cls(19)
                
                @schemas.classproperty
                def POSITIVE_20(cls):
                    return cls(20)
                
                @schemas.classproperty
                def POSITIVE_21(cls):
                    return cls(21)
                
                @schemas.classproperty
                def POSITIVE_22(cls):
                    return cls(22)
                
                @schemas.classproperty
                def POSITIVE_23(cls):
                    return cls(23)
                
                @schemas.classproperty
                def POSITIVE_24(cls):
                    return cls(24)
                
                @schemas.classproperty
                def POSITIVE_25(cls):
                    return cls(25)
                
                @schemas.classproperty
                def POSITIVE_26(cls):
                    return cls(26)
                
                @schemas.classproperty
                def POSITIVE_27(cls):
                    return cls(27)
                
                @schemas.classproperty
                def POSITIVE_28(cls):
                    return cls(28)
                
                @schemas.classproperty
                def POSITIVE_29(cls):
                    return cls(29)
                
                @schemas.classproperty
                def POSITIVE_30(cls):
                    return cls(30)
                
                @schemas.classproperty
                def POSITIVE_31(cls):
                    return cls(31)
                
                @schemas.classproperty
                def POSITIVE_32(cls):
                    return cls(32)
                
                @schemas.classproperty
                def POSITIVE_33(cls):
                    return cls(33)
                
                @schemas.classproperty
                def POSITIVE_34(cls):
                    return cls(34)
                
                @schemas.classproperty
                def POSITIVE_35(cls):
                    return cls(35)
                
                @schemas.classproperty
                def POSITIVE_36(cls):
                    return cls(36)
                
                @schemas.classproperty
                def POSITIVE_37(cls):
                    return cls(37)
                
                @schemas.classproperty
                def POSITIVE_38(cls):
                    return cls(38)
                
                @schemas.classproperty
                def POSITIVE_39(cls):
                    return cls(39)
                
                @schemas.classproperty
                def POSITIVE_40(cls):
                    return cls(40)
                
                @schemas.classproperty
                def POSITIVE_41(cls):
                    return cls(41)
                
                @schemas.classproperty
                def POSITIVE_42(cls):
                    return cls(42)
                
                @schemas.classproperty
                def POSITIVE_43(cls):
                    return cls(43)
                
                @schemas.classproperty
                def POSITIVE_44(cls):
                    return cls(44)
                
                @schemas.classproperty
                def POSITIVE_45(cls):
                    return cls(45)
                
                @schemas.classproperty
                def POSITIVE_46(cls):
                    return cls(46)
                
                @schemas.classproperty
                def POSITIVE_47(cls):
                    return cls(47)
                
                @schemas.classproperty
                def POSITIVE_48(cls):
                    return cls(48)
                
                @schemas.classproperty
                def POSITIVE_49(cls):
                    return cls(49)
                
                @schemas.classproperty
                def POSITIVE_50(cls):
                    return cls(50)
                
                @schemas.classproperty
                def POSITIVE_51(cls):
                    return cls(51)
                
                @schemas.classproperty
                def POSITIVE_52(cls):
                    return cls(52)
                
                @schemas.classproperty
                def POSITIVE_53(cls):
                    return cls(53)
                
                @schemas.classproperty
                def POSITIVE_54(cls):
                    return cls(54)
                
                @schemas.classproperty
                def POSITIVE_55(cls):
                    return cls(55)
                
                @schemas.classproperty
                def POSITIVE_56(cls):
                    return cls(56)
                
                @schemas.classproperty
                def POSITIVE_57(cls):
                    return cls(57)
                
                @schemas.classproperty
                def POSITIVE_58(cls):
                    return cls(58)
                
                @schemas.classproperty
                def POSITIVE_59(cls):
                    return cls(59)
                
                @schemas.classproperty
                def POSITIVE_60(cls):
                    return cls(60)
                
                @schemas.classproperty
                def POSITIVE_61(cls):
                    return cls(61)
                
                @schemas.classproperty
                def POSITIVE_62(cls):
                    return cls(62)
                
                @schemas.classproperty
                def POSITIVE_63(cls):
                    return cls(63)
                
                @schemas.classproperty
                def POSITIVE_64(cls):
                    return cls(64)
                
                @schemas.classproperty
                def POSITIVE_65(cls):
                    return cls(65)
                
                @schemas.classproperty
                def POSITIVE_66(cls):
                    return cls(66)
                
                @schemas.classproperty
                def POSITIVE_67(cls):
                    return cls(67)
                
                @schemas.classproperty
                def POSITIVE_68(cls):
                    return cls(68)
                
                @schemas.classproperty
                def POSITIVE_69(cls):
                    return cls(69)
                
                @schemas.classproperty
                def POSITIVE_70(cls):
                    return cls(70)
                
                @schemas.classproperty
                def POSITIVE_71(cls):
                    return cls(71)
                
                @schemas.classproperty
                def POSITIVE_72(cls):
                    return cls(72)
                
                @schemas.classproperty
                def POSITIVE_73(cls):
                    return cls(73)
                
                @schemas.classproperty
                def POSITIVE_74(cls):
                    return cls(74)
                
                @schemas.classproperty
                def POSITIVE_75(cls):
                    return cls(75)
                
                @schemas.classproperty
                def POSITIVE_76(cls):
                    return cls(76)
                
                @schemas.classproperty
                def POSITIVE_77(cls):
                    return cls(77)
                
                @schemas.classproperty
                def POSITIVE_78(cls):
                    return cls(78)
                
                @schemas.classproperty
                def POSITIVE_79(cls):
                    return cls(79)
                
                @schemas.classproperty
                def POSITIVE_80(cls):
                    return cls(80)
                
                @schemas.classproperty
                def POSITIVE_81(cls):
                    return cls(81)
                
                @schemas.classproperty
                def POSITIVE_82(cls):
                    return cls(82)
                
                @schemas.classproperty
                def POSITIVE_83(cls):
                    return cls(83)
                
                @schemas.classproperty
                def POSITIVE_84(cls):
                    return cls(84)
                
                @schemas.classproperty
                def POSITIVE_85(cls):
                    return cls(85)
                
                @schemas.classproperty
                def POSITIVE_86(cls):
                    return cls(86)
                
                @schemas.classproperty
                def POSITIVE_87(cls):
                    return cls(87)
                
                @schemas.classproperty
                def POSITIVE_88(cls):
                    return cls(88)
                
                @schemas.classproperty
                def POSITIVE_89(cls):
                    return cls(89)
                
                @schemas.classproperty
                def POSITIVE_90(cls):
                    return cls(90)
                
                @schemas.classproperty
                def POSITIVE_91(cls):
                    return cls(91)
                
                @schemas.classproperty
                def POSITIVE_92(cls):
                    return cls(92)
                
                @schemas.classproperty
                def POSITIVE_95(cls):
                    return cls(95)
                
                @schemas.classproperty
                def POSITIVE_96(cls):
                    return cls(96)
                
                @schemas.classproperty
                def POSITIVE_100(cls):
                    return cls(100)
                
                @schemas.classproperty
                def POSITIVE_101(cls):
                    return cls(101)
                
                @schemas.classproperty
                def POSITIVE_102(cls):
                    return cls(102)
                
                @schemas.classproperty
                def POSITIVE_103(cls):
                    return cls(103)
                
                @schemas.classproperty
                def POSITIVE_104(cls):
                    return cls(104)
                
                @schemas.classproperty
                def POSITIVE_105(cls):
                    return cls(105)
                
                @schemas.classproperty
                def POSITIVE_106(cls):
                    return cls(106)
                
                @schemas.classproperty
                def POSITIVE_110(cls):
                    return cls(110)
                
                @schemas.classproperty
                def POSITIVE_111(cls):
                    return cls(111)
                
                @schemas.classproperty
                def POSITIVE_112(cls):
                    return cls(112)
                
                @schemas.classproperty
                def POSITIVE_113(cls):
                    return cls(113)
                
                @schemas.classproperty
                def POSITIVE_114(cls):
                    return cls(114)
                
                @schemas.classproperty
                def POSITIVE_115(cls):
                    return cls(115)
                
                @schemas.classproperty
                def POSITIVE_116(cls):
                    return cls(116)
                
                @schemas.classproperty
                def POSITIVE_117(cls):
                    return cls(117)
                
                @schemas.classproperty
                def POSITIVE_118(cls):
                    return cls(118)
                
                @schemas.classproperty
                def POSITIVE_119(cls):
                    return cls(119)
                
                @schemas.classproperty
                def POSITIVE_120(cls):
                    return cls(120)
                
                @schemas.classproperty
                def POSITIVE_121(cls):
                    return cls(121)
                
                @schemas.classproperty
                def POSITIVE_122(cls):
                    return cls(122)
                
                @schemas.classproperty
                def POSITIVE_123(cls):
                    return cls(123)
                
                @schemas.classproperty
                def POSITIVE_124(cls):
                    return cls(124)
                
                @schemas.classproperty
                def POSITIVE_125(cls):
                    return cls(125)
                
                @schemas.classproperty
                def POSITIVE_126(cls):
                    return cls(126)
                
                @schemas.classproperty
                def POSITIVE_127(cls):
                    return cls(127)
                
                @schemas.classproperty
                def POSITIVE_128(cls):
                    return cls(128)
                
                @schemas.classproperty
                def POSITIVE_129(cls):
                    return cls(129)
                
                @schemas.classproperty
                def POSITIVE_130(cls):
                    return cls(130)
                
                @schemas.classproperty
                def POSITIVE_131(cls):
                    return cls(131)
                
                @schemas.classproperty
                def POSITIVE_132(cls):
                    return cls(132)
                
                @schemas.classproperty
                def POSITIVE_133(cls):
                    return cls(133)
                
                @schemas.classproperty
                def POSITIVE_134(cls):
                    return cls(134)
                
                @schemas.classproperty
                def POSITIVE_135(cls):
                    return cls(135)
                
                @schemas.classproperty
                def POSITIVE_136(cls):
                    return cls(136)
                
                @schemas.classproperty
                def POSITIVE_137(cls):
                    return cls(137)
                
                @schemas.classproperty
                def POSITIVE_138(cls):
                    return cls(138)
                
                @schemas.classproperty
                def POSITIVE_139(cls):
                    return cls(139)
                
                @schemas.classproperty
                def POSITIVE_140(cls):
                    return cls(140)
                
                @schemas.classproperty
                def POSITIVE_141(cls):
                    return cls(141)
                
                @schemas.classproperty
                def POSITIVE_145(cls):
                    return cls(145)
                
                @schemas.classproperty
                def POSITIVE_146(cls):
                    return cls(146)
                
                @schemas.classproperty
                def POSITIVE_147(cls):
                    return cls(147)
                
                @schemas.classproperty
                def POSITIVE_148(cls):
                    return cls(148)
                
                @schemas.classproperty
                def POSITIVE_149(cls):
                    return cls(149)
                
                @schemas.classproperty
                def POSITIVE_150(cls):
                    return cls(150)
                
                @schemas.classproperty
                def POSITIVE_151(cls):
                    return cls(151)
                
                @schemas.classproperty
                def POSITIVE_152(cls):
                    return cls(152)
                
                @schemas.classproperty
                def POSITIVE_153(cls):
                    return cls(153)
                
                @schemas.classproperty
                def POSITIVE_154(cls):
                    return cls(154)
                
                @schemas.classproperty
                def POSITIVE_155(cls):
                    return cls(155)
                
                @schemas.classproperty
                def POSITIVE_156(cls):
                    return cls(156)
                
                @schemas.classproperty
                def POSITIVE_157(cls):
                    return cls(157)
                
                @schemas.classproperty
                def POSITIVE_158(cls):
                    return cls(158)
                
                @schemas.classproperty
                def POSITIVE_159(cls):
                    return cls(159)
                
                @schemas.classproperty
                def POSITIVE_160(cls):
                    return cls(160)
                
                @schemas.classproperty
                def POSITIVE_161(cls):
                    return cls(161)
                
                @schemas.classproperty
                def POSITIVE_162(cls):
                    return cls(162)
                
                @schemas.classproperty
                def POSITIVE_163(cls):
                    return cls(163)
                
                @schemas.classproperty
                def POSITIVE_164(cls):
                    return cls(164)
                
                @schemas.classproperty
                def POSITIVE_165(cls):
                    return cls(165)
                
                @schemas.classproperty
                def POSITIVE_166(cls):
                    return cls(166)
                
                @schemas.classproperty
                def POSITIVE_167(cls):
                    return cls(167)
                
                @schemas.classproperty
                def POSITIVE_168(cls):
                    return cls(168)
                
                @schemas.classproperty
                def POSITIVE_169(cls):
                    return cls(169)
                
                @schemas.classproperty
                def POSITIVE_170(cls):
                    return cls(170)
                
                @schemas.classproperty
                def POSITIVE_171(cls):
                    return cls(171)
                
                @schemas.classproperty
                def POSITIVE_172(cls):
                    return cls(172)
                
                @schemas.classproperty
                def POSITIVE_173(cls):
                    return cls(173)
                
                @schemas.classproperty
                def POSITIVE_174(cls):
                    return cls(174)
                
                @schemas.classproperty
                def POSITIVE_175(cls):
                    return cls(175)
                
                @schemas.classproperty
                def POSITIVE_176(cls):
                    return cls(176)
                
                @schemas.classproperty
                def POSITIVE_177(cls):
                    return cls(177)
                
                @schemas.classproperty
                def POSITIVE_178(cls):
                    return cls(178)
                
                @schemas.classproperty
                def POSITIVE_179(cls):
                    return cls(179)
                
                @schemas.classproperty
                def POSITIVE_180(cls):
                    return cls(180)
                
                @schemas.classproperty
                def POSITIVE_181(cls):
                    return cls(181)
                
                @schemas.classproperty
                def POSITIVE_182(cls):
                    return cls(182)
                
                @schemas.classproperty
                def POSITIVE_183(cls):
                    return cls(183)
                
                @schemas.classproperty
                def POSITIVE_184(cls):
                    return cls(184)
                
                @schemas.classproperty
                def POSITIVE_185(cls):
                    return cls(185)
                
                @schemas.classproperty
                def POSITIVE_186(cls):
                    return cls(186)
                
                @schemas.classproperty
                def POSITIVE_187(cls):
                    return cls(187)
                
                @schemas.classproperty
                def POSITIVE_188(cls):
                    return cls(188)
                
                @schemas.classproperty
                def POSITIVE_189(cls):
                    return cls(189)
                
                @schemas.classproperty
                def POSITIVE_190(cls):
                    return cls(190)
                
                @schemas.classproperty
                def POSITIVE_191(cls):
                    return cls(191)
                
                @schemas.classproperty
                def POSITIVE_192(cls):
                    return cls(192)
                
                @schemas.classproperty
                def POSITIVE_193(cls):
                    return cls(193)
                
                @schemas.classproperty
                def POSITIVE_194(cls):
                    return cls(194)
                
                @schemas.classproperty
                def POSITIVE_195(cls):
                    return cls(195)
                
                @schemas.classproperty
                def POSITIVE_196(cls):
                    return cls(196)
                
                @schemas.classproperty
                def POSITIVE_197(cls):
                    return cls(197)
                
                @schemas.classproperty
                def POSITIVE_198(cls):
                    return cls(198)
                
                @schemas.classproperty
                def POSITIVE_199(cls):
                    return cls(199)
                
                @schemas.classproperty
                def POSITIVE_200(cls):
                    return cls(200)
                
                @schemas.classproperty
                def POSITIVE_201(cls):
                    return cls(201)
                
                @schemas.classproperty
                def POSITIVE_202(cls):
                    return cls(202)
                
                @schemas.classproperty
                def POSITIVE_203(cls):
                    return cls(203)
                
                @schemas.classproperty
                def POSITIVE_204(cls):
                    return cls(204)
                
                @schemas.classproperty
                def POSITIVE_205(cls):
                    return cls(205)
                
                @schemas.classproperty
                def POSITIVE_206(cls):
                    return cls(206)
                
                @schemas.classproperty
                def POSITIVE_207(cls):
                    return cls(207)
                
                @schemas.classproperty
                def POSITIVE_208(cls):
                    return cls(208)
                
                @schemas.classproperty
                def POSITIVE_209(cls):
                    return cls(209)
                
                @schemas.classproperty
                def POSITIVE_210(cls):
                    return cls(210)
                
                @schemas.classproperty
                def POSITIVE_211(cls):
                    return cls(211)
                
                @schemas.classproperty
                def POSITIVE_212(cls):
                    return cls(212)
                
                @schemas.classproperty
                def POSITIVE_213(cls):
                    return cls(213)
                
                @schemas.classproperty
                def POSITIVE_214(cls):
                    return cls(214)
                
                @schemas.classproperty
                def POSITIVE_215(cls):
                    return cls(215)
                
                @schemas.classproperty
                def POSITIVE_216(cls):
                    return cls(216)
                
                @schemas.classproperty
                def POSITIVE_217(cls):
                    return cls(217)
                
                @schemas.classproperty
                def POSITIVE_218(cls):
                    return cls(218)
                
                @schemas.classproperty
                def POSITIVE_219(cls):
                    return cls(219)
                
                @schemas.classproperty
                def POSITIVE_220(cls):
                    return cls(220)
                
                @schemas.classproperty
                def POSITIVE_221(cls):
                    return cls(221)
                
                @schemas.classproperty
                def POSITIVE_222(cls):
                    return cls(222)
                
                @schemas.classproperty
                def POSITIVE_223(cls):
                    return cls(223)
                
                @schemas.classproperty
                def POSITIVE_224(cls):
                    return cls(224)
                
                @schemas.classproperty
                def POSITIVE_225(cls):
                    return cls(225)
                
                @schemas.classproperty
                def POSITIVE_226(cls):
                    return cls(226)
                
                @schemas.classproperty
                def POSITIVE_227(cls):
                    return cls(227)
                
                @schemas.classproperty
                def POSITIVE_228(cls):
                    return cls(228)
                
                @schemas.classproperty
                def POSITIVE_229(cls):
                    return cls(229)
                
                @schemas.classproperty
                def POSITIVE_230(cls):
                    return cls(230)
                
                @schemas.classproperty
                def POSITIVE_231(cls):
                    return cls(231)
                
                @schemas.classproperty
                def POSITIVE_232(cls):
                    return cls(232)
                
                @schemas.classproperty
                def POSITIVE_233(cls):
                    return cls(233)
                
                @schemas.classproperty
                def POSITIVE_234(cls):
                    return cls(234)
                
                @schemas.classproperty
                def POSITIVE_235(cls):
                    return cls(235)
                
                @schemas.classproperty
                def POSITIVE_236(cls):
                    return cls(236)
                
                @schemas.classproperty
                def POSITIVE_237(cls):
                    return cls(237)
                
                @schemas.classproperty
                def POSITIVE_238(cls):
                    return cls(238)
                
                @schemas.classproperty
                def POSITIVE_239(cls):
                    return cls(239)
                
                @schemas.classproperty
                def POSITIVE_240(cls):
                    return cls(240)
                
                @schemas.classproperty
                def POSITIVE_241(cls):
                    return cls(241)
                
                @schemas.classproperty
                def POSITIVE_242(cls):
                    return cls(242)
                
                @schemas.classproperty
                def POSITIVE_243(cls):
                    return cls(243)
                
                @schemas.classproperty
                def POSITIVE_244(cls):
                    return cls(244)
                
                @schemas.classproperty
                def POSITIVE_245(cls):
                    return cls(245)
                
                @schemas.classproperty
                def POSITIVE_246(cls):
                    return cls(246)
                
                @schemas.classproperty
                def POSITIVE_247(cls):
                    return cls(247)
                
                @schemas.classproperty
                def POSITIVE_248(cls):
                    return cls(248)
                
                @schemas.classproperty
                def POSITIVE_249(cls):
                    return cls(249)
                
                @schemas.classproperty
                def POSITIVE_250(cls):
                    return cls(250)
                
                @schemas.classproperty
                def POSITIVE_251(cls):
                    return cls(251)
                
                @schemas.classproperty
                def POSITIVE_252(cls):
                    return cls(252)
                
                @schemas.classproperty
                def POSITIVE_253(cls):
                    return cls(253)
                
                @schemas.classproperty
                def POSITIVE_254(cls):
                    return cls(254)
                
                @schemas.classproperty
                def POSITIVE_255(cls):
                    return cls(255)
                
                @schemas.classproperty
                def POSITIVE_291(cls):
                    return cls(291)
                
                @schemas.classproperty
                def POSITIVE_300(cls):
                    return cls(300)
                
                @schemas.classproperty
                def POSITIVE_301(cls):
                    return cls(301)
                
                @schemas.classproperty
                def POSITIVE_303(cls):
                    return cls(303)
                
                @schemas.classproperty
                def POSITIVE_304(cls):
                    return cls(304)
                
                @schemas.classproperty
                def POSITIVE_305(cls):
                    return cls(305)
                
                @schemas.classproperty
                def POSITIVE_306(cls):
                    return cls(306)
                
                @schemas.classproperty
                def POSITIVE_307(cls):
                    return cls(307)
                
                @schemas.classproperty
                def POSITIVE_330(cls):
                    return cls(330)
                
                @schemas.classproperty
                def POSITIVE_331(cls):
                    return cls(331)
                
                @schemas.classproperty
                def POSITIVE_332(cls):
                    return cls(332)
                
                @schemas.classproperty
                def POSITIVE_333(cls):
                    return cls(333)
                
                @schemas.classproperty
                def POSITIVE_334(cls):
                    return cls(334)
                
                @schemas.classproperty
                def POSITIVE_400(cls):
                    return cls(400)
                
                @schemas.classproperty
                def POSITIVE_401(cls):
                    return cls(401)
                
                @schemas.classproperty
                def POSITIVE_402(cls):
                    return cls(402)
                
                @schemas.classproperty
                def POSITIVE_410(cls):
                    return cls(410)
                
                @schemas.classproperty
                def POSITIVE_411(cls):
                    return cls(411)
                
                @schemas.classproperty
                def POSITIVE_412(cls):
                    return cls(412)
                
                @schemas.classproperty
                def POSITIVE_501(cls):
                    return cls(501)
                
                @schemas.classproperty
                def POSITIVE_502(cls):
                    return cls(502)
                
                @schemas.classproperty
                def POSITIVE_503(cls):
                    return cls(503)
                
                @schemas.classproperty
                def POSITIVE_510(cls):
                    return cls(510)
                
                @schemas.classproperty
                def POSITIVE_511(cls):
                    return cls(511)
                
                @schemas.classproperty
                def POSITIVE_512(cls):
                    return cls(512)
                
                @schemas.classproperty
                def POSITIVE_513(cls):
                    return cls(513)
                
                @schemas.classproperty
                def POSITIVE_514(cls):
                    return cls(514)
                
                @schemas.classproperty
                def POSITIVE_515(cls):
                    return cls(515)
                
                @schemas.classproperty
                def POSITIVE_516(cls):
                    return cls(516)
                
                @schemas.classproperty
                def POSITIVE_517(cls):
                    return cls(517)
                
                @schemas.classproperty
                def POSITIVE_518(cls):
                    return cls(518)
                
                @schemas.classproperty
                def POSITIVE_519(cls):
                    return cls(519)
                
                @schemas.classproperty
                def POSITIVE_520(cls):
                    return cls(520)
                
                @schemas.classproperty
                def POSITIVE_521(cls):
                    return cls(521)
                
                @schemas.classproperty
                def POSITIVE_522(cls):
                    return cls(522)
                
                @schemas.classproperty
                def POSITIVE_523(cls):
                    return cls(523)
                
                @schemas.classproperty
                def POSITIVE_524(cls):
                    return cls(524)
                
                @schemas.classproperty
                def POSITIVE_525(cls):
                    return cls(525)
                
                @schemas.classproperty
                def POSITIVE_526(cls):
                    return cls(526)
                
                @schemas.classproperty
                def POSITIVE_527(cls):
                    return cls(527)
                
                @schemas.classproperty
                def POSITIVE_528(cls):
                    return cls(528)
                
                @schemas.classproperty
                def POSITIVE_529(cls):
                    return cls(529)
                
                @schemas.classproperty
                def POSITIVE_530(cls):
                    return cls(530)
                
                @schemas.classproperty
                def POSITIVE_531(cls):
                    return cls(531)
                
                @schemas.classproperty
                def POSITIVE_532(cls):
                    return cls(532)
                
                @schemas.classproperty
                def POSITIVE_533(cls):
                    return cls(533)
                
                @schemas.classproperty
                def POSITIVE_534(cls):
                    return cls(534)
                
                @schemas.classproperty
                def POSITIVE_535(cls):
                    return cls(535)
                
                @schemas.classproperty
                def POSITIVE_536(cls):
                    return cls(536)
                
                @schemas.classproperty
                def POSITIVE_537(cls):
                    return cls(537)
                
                @schemas.classproperty
                def POSITIVE_538(cls):
                    return cls(538)
                
                @schemas.classproperty
                def POSITIVE_539(cls):
                    return cls(539)
                
                @schemas.classproperty
                def POSITIVE_540(cls):
                    return cls(540)
                
                @schemas.classproperty
                def POSITIVE_541(cls):
                    return cls(541)
                
                @schemas.classproperty
                def POSITIVE_542(cls):
                    return cls(542)
                
                @schemas.classproperty
                def POSITIVE_545(cls):
                    return cls(545)
                
                @schemas.classproperty
                def POSITIVE_546(cls):
                    return cls(546)
                
                @schemas.classproperty
                def POSITIVE_550(cls):
                    return cls(550)
                
                @schemas.classproperty
                def POSITIVE_551(cls):
                    return cls(551)
                
                @schemas.classproperty
                def POSITIVE_552(cls):
                    return cls(552)
                
                @schemas.classproperty
                def POSITIVE_553(cls):
                    return cls(553)
                
                @schemas.classproperty
                def POSITIVE_554(cls):
                    return cls(554)
                
                @schemas.classproperty
                def POSITIVE_555(cls):
                    return cls(555)
                
                @schemas.classproperty
                def POSITIVE_600(cls):
                    return cls(600)
                
                @schemas.classproperty
                def POSITIVE_601(cls):
                    return cls(601)
                
                @schemas.classproperty
                def POSITIVE_602(cls):
                    return cls(602)
                
                @schemas.classproperty
                def POSITIVE_700(cls):
                    return cls(700)
                
                @schemas.classproperty
                def POSITIVE_701(cls):
                    return cls(701)
                
                @schemas.classproperty
                def POSITIVE_702(cls):
                    return cls(702)
                
                @schemas.classproperty
                def POSITIVE_703(cls):
                    return cls(703)
                
                @schemas.classproperty
                def POSITIVE_704(cls):
                    return cls(704)
                
                @schemas.classproperty
                def POSITIVE_705(cls):
                    return cls(705)
                
                @schemas.classproperty
                def POSITIVE_706(cls):
                    return cls(706)
                
                @schemas.classproperty
                def POSITIVE_800(cls):
                    return cls(800)
                
                @schemas.classproperty
                def POSITIVE_801(cls):
                    return cls(801)
                
                @schemas.classproperty
                def POSITIVE_802(cls):
                    return cls(802)
                
                @schemas.classproperty
                def POSITIVE_803(cls):
                    return cls(803)
                
                @schemas.classproperty
                def POSITIVE_804(cls):
                    return cls(804)
                
                @schemas.classproperty
                def POSITIVE_805(cls):
                    return cls(805)
                
                @schemas.classproperty
                def POSITIVE_900(cls):
                    return cls(900)
                
                @schemas.classproperty
                def POSITIVE_901(cls):
                    return cls(901)
                
                @schemas.classproperty
                def POSITIVE_902(cls):
                    return cls(902)
                
                @schemas.classproperty
                def POSITIVE_903(cls):
                    return cls(903)
                
                @schemas.classproperty
                def POSITIVE_904(cls):
                    return cls(904)
                
                @schemas.classproperty
                def POSITIVE_905(cls):
                    return cls(905)
                
                @schemas.classproperty
                def POSITIVE_906(cls):
                    return cls(906)
                
                @schemas.classproperty
                def POSITIVE_907(cls):
                    return cls(907)
                
                @schemas.classproperty
                def POSITIVE_911(cls):
                    return cls(911)
                
                @schemas.classproperty
                def POSITIVE_912(cls):
                    return cls(912)
                
                @schemas.classproperty
                def POSITIVE_931(cls):
                    return cls(931)
                
                @schemas.classproperty
                def POSITIVE_932(cls):
                    return cls(932)
                
                @schemas.classproperty
                def POSITIVE_950(cls):
                    return cls(950)
                
                @schemas.classproperty
                def POSITIVE_1001(cls):
                    return cls(1001)
                
                @schemas.classproperty
                def POSITIVE_1002(cls):
                    return cls(1002)
                
                @schemas.classproperty
                def POSITIVE_1010(cls):
                    return cls(1010)
                
                @schemas.classproperty
                def POSITIVE_1100(cls):
                    return cls(1100)
                
                @schemas.classproperty
                def POSITIVE_1101(cls):
                    return cls(1101)
                
                @schemas.classproperty
                def POSITIVE_1200(cls):
                    return cls(1200)
                
                @schemas.classproperty
                def POSITIVE_1201(cls):
                    return cls(1201)
                
                @schemas.classproperty
                def POSITIVE_1244(cls):
                    return cls(1244)
                
                @schemas.classproperty
                def POSITIVE_1245(cls):
                    return cls(1245)
                
                @schemas.classproperty
                def POSITIVE_1300(cls):
                    return cls(1300)
                
                @schemas.classproperty
                def POSITIVE_1301(cls):
                    return cls(1301)
                
                @schemas.classproperty
                def POSITIVE_1302(cls):
                    return cls(1302)
                
                @schemas.classproperty
                def POSITIVE_1303(cls):
                    return cls(1303)
                
                @schemas.classproperty
                def POSITIVE_1304(cls):
                    return cls(1304)
                
                @schemas.classproperty
                def POSITIVE_1305(cls):
                    return cls(1305)
                
                @schemas.classproperty
                def POSITIVE_1400(cls):
                    return cls(1400)
                
                @schemas.classproperty
                def POSITIVE_1401(cls):
                    return cls(1401)
                
                @schemas.classproperty
                def POSITIVE_1402(cls):
                    return cls(1402)
                
                @schemas.classproperty
                def POSITIVE_1403(cls):
                    return cls(1403)
                
                @schemas.classproperty
                def POSITIVE_1404(cls):
                    return cls(1404)
                
                @schemas.classproperty
                def POSITIVE_1405(cls):
                    return cls(1405)
                
                @schemas.classproperty
                def POSITIVE_1406(cls):
                    return cls(1406)
                
                @schemas.classproperty
                def POSITIVE_1407(cls):
                    return cls(1407)
                
                @schemas.classproperty
                def POSITIVE_1408(cls):
                    return cls(1408)
                
                @schemas.classproperty
                def POSITIVE_1409(cls):
                    return cls(1409)
                
                @schemas.classproperty
                def POSITIVE_1410(cls):
                    return cls(1410)
                
                @schemas.classproperty
                def POSITIVE_1411(cls):
                    return cls(1411)
                
                @schemas.classproperty
                def POSITIVE_1412(cls):
                    return cls(1412)
                
                @schemas.classproperty
                def POSITIVE_1413(cls):
                    return cls(1413)
                
                @schemas.classproperty
                def POSITIVE_1414(cls):
                    return cls(1414)
                
                @schemas.classproperty
                def POSITIVE_1415(cls):
                    return cls(1415)
                
                @schemas.classproperty
                def POSITIVE_1416(cls):
                    return cls(1416)
                
                @schemas.classproperty
                def POSITIVE_1417(cls):
                    return cls(1417)
                
                @schemas.classproperty
                def POSITIVE_1418(cls):
                    return cls(1418)
                
                @schemas.classproperty
                def POSITIVE_1419(cls):
                    return cls(1419)
                
                @schemas.classproperty
                def POSITIVE_1420(cls):
                    return cls(1420)
                
                @schemas.classproperty
                def POSITIVE_1421(cls):
                    return cls(1421)
                
                @schemas.classproperty
                def POSITIVE_1422(cls):
                    return cls(1422)
                
                @schemas.classproperty
                def POSITIVE_1423(cls):
                    return cls(1423)
                
                @schemas.classproperty
                def POSITIVE_1424(cls):
                    return cls(1424)
                
                @schemas.classproperty
                def POSITIVE_1500(cls):
                    return cls(1500)
                
                @schemas.classproperty
                def POSITIVE_1501(cls):
                    return cls(1501)
                
                @schemas.classproperty
                def POSITIVE_1502(cls):
                    return cls(1502)
                
                @schemas.classproperty
                def POSITIVE_1503(cls):
                    return cls(1503)
                
                @schemas.classproperty
                def POSITIVE_1504(cls):
                    return cls(1504)
                
                @schemas.classproperty
                def POSITIVE_1505(cls):
                    return cls(1505)
                
                @schemas.classproperty
                def POSITIVE_1506(cls):
                    return cls(1506)
                
                @schemas.classproperty
                def POSITIVE_1507(cls):
                    return cls(1507)
                
                @schemas.classproperty
                def POSITIVE_1508(cls):
                    return cls(1508)
                
                @schemas.classproperty
                def POSITIVE_1509(cls):
                    return cls(1509)
                
                @schemas.classproperty
                def POSITIVE_1510(cls):
                    return cls(1510)
                
                @schemas.classproperty
                def POSITIVE_1511(cls):
                    return cls(1511)
                
                @schemas.classproperty
                def POSITIVE_1512(cls):
                    return cls(1512)
                
                @schemas.classproperty
                def POSITIVE_1513(cls):
                    return cls(1513)
                
                @schemas.classproperty
                def POSITIVE_1514(cls):
                    return cls(1514)
                
                @schemas.classproperty
                def POSITIVE_1600(cls):
                    return cls(1600)
                
                @schemas.classproperty
                def POSITIVE_1601(cls):
                    return cls(1601)
                
                @schemas.classproperty
                def POSITIVE_1602(cls):
                    return cls(1602)
                
                @schemas.classproperty
                def POSITIVE_1603(cls):
                    return cls(1603)
                
                @schemas.classproperty
                def POSITIVE_1604(cls):
                    return cls(1604)
                
                @schemas.classproperty
                def POSITIVE_1605(cls):
                    return cls(1605)
                
                @schemas.classproperty
                def POSITIVE_1606(cls):
                    return cls(1606)
                
                @schemas.classproperty
                def POSITIVE_1607(cls):
                    return cls(1607)
                
                @schemas.classproperty
                def POSITIVE_1608(cls):
                    return cls(1608)
                
                @schemas.classproperty
                def POSITIVE_1609(cls):
                    return cls(1609)
                
                @schemas.classproperty
                def POSITIVE_1700(cls):
                    return cls(1700)
                
                @schemas.classproperty
                def POSITIVE_1701(cls):
                    return cls(1701)
                
                @schemas.classproperty
                def POSITIVE_1702(cls):
                    return cls(1702)
                
                @schemas.classproperty
                def POSITIVE_1801(cls):
                    return cls(1801)
                
                @schemas.classproperty
                def POSITIVE_1802(cls):
                    return cls(1802)
                
                @schemas.classproperty
                def POSITIVE_1900(cls):
                    return cls(1900)
                
                @schemas.classproperty
                def POSITIVE_1901(cls):
                    return cls(1901)
                
                @schemas.classproperty
                def POSITIVE_1902(cls):
                    return cls(1902)
                
                @schemas.classproperty
                def POSITIVE_1903(cls):
                    return cls(1903)
                
                @schemas.classproperty
                def POSITIVE_1904(cls):
                    return cls(1904)
                
                @schemas.classproperty
                def POSITIVE_1905(cls):
                    return cls(1905)
                
                @schemas.classproperty
                def POSITIVE_2000(cls):
                    return cls(2000)
                
                @schemas.classproperty
                def POSITIVE_2001(cls):
                    return cls(2001)
                
                @schemas.classproperty
                def POSITIVE_2002(cls):
                    return cls(2002)
                
                @schemas.classproperty
                def POSITIVE_2003(cls):
                    return cls(2003)
                
                @schemas.classproperty
                def POSITIVE_2004(cls):
                    return cls(2004)
                
                @schemas.classproperty
                def POSITIVE_2005(cls):
                    return cls(2005)
                
                @schemas.classproperty
                def POSITIVE_2006(cls):
                    return cls(2006)
                
                @schemas.classproperty
                def POSITIVE_2007(cls):
                    return cls(2007)
                
                @schemas.classproperty
                def POSITIVE_2008(cls):
                    return cls(2008)
                
                @schemas.classproperty
                def POSITIVE_2009(cls):
                    return cls(2009)
                
                @schemas.classproperty
                def POSITIVE_2010(cls):
                    return cls(2010)
                
                @schemas.classproperty
                def POSITIVE_2011(cls):
                    return cls(2011)
                
                @schemas.classproperty
                def POSITIVE_2012(cls):
                    return cls(2012)
                
                @schemas.classproperty
                def POSITIVE_2013(cls):
                    return cls(2013)
                
                @schemas.classproperty
                def POSITIVE_2014(cls):
                    return cls(2014)
                
                @schemas.classproperty
                def POSITIVE_2015(cls):
                    return cls(2015)
                
                @schemas.classproperty
                def POSITIVE_2016(cls):
                    return cls(2016)
                
                @schemas.classproperty
                def POSITIVE_2017(cls):
                    return cls(2017)
                
                @schemas.classproperty
                def POSITIVE_2018(cls):
                    return cls(2018)
                
                @schemas.classproperty
                def POSITIVE_2100(cls):
                    return cls(2100)
                
                @schemas.classproperty
                def POSITIVE_2101(cls):
                    return cls(2101)
                
                @schemas.classproperty
                def POSITIVE_2102(cls):
                    return cls(2102)
                
                @schemas.classproperty
                def POSITIVE_2103(cls):
                    return cls(2103)
                
                @schemas.classproperty
                def POSITIVE_2104(cls):
                    return cls(2104)
                
                @schemas.classproperty
                def POSITIVE_2105(cls):
                    return cls(2105)
                
                @schemas.classproperty
                def POSITIVE_2106(cls):
                    return cls(2106)
                
                @schemas.classproperty
                def POSITIVE_2107(cls):
                    return cls(2107)
                
                @schemas.classproperty
                def POSITIVE_2108(cls):
                    return cls(2108)
                
                @schemas.classproperty
                def POSITIVE_2109(cls):
                    return cls(2109)
                
                @schemas.classproperty
                def POSITIVE_2110(cls):
                    return cls(2110)
                
                @schemas.classproperty
                def POSITIVE_2111(cls):
                    return cls(2111)
                
                @schemas.classproperty
                def POSITIVE_2112(cls):
                    return cls(2112)
                
                @schemas.classproperty
                def POSITIVE_2113(cls):
                    return cls(2113)
                
                @schemas.classproperty
                def POSITIVE_2114(cls):
                    return cls(2114)
                
                @schemas.classproperty
                def POSITIVE_2201(cls):
                    return cls(2201)
                
                @schemas.classproperty
                def POSITIVE_2202(cls):
                    return cls(2202)
                
                @schemas.classproperty
                def POSITIVE_2203(cls):
                    return cls(2203)
                
                @schemas.classproperty
                def POSITIVE_2204(cls):
                    return cls(2204)
                
                @schemas.classproperty
                def POSITIVE_3000(cls):
                    return cls(3000)
                
                @schemas.classproperty
                def POSITIVE_3001(cls):
                    return cls(3001)
                
                @schemas.classproperty
                def POSITIVE_3002(cls):
                    return cls(3002)
                
                @schemas.classproperty
                def POSITIVE_3003(cls):
                    return cls(3003)
                
                @schemas.classproperty
                def POSITIVE_3004(cls):
                    return cls(3004)
                
                @schemas.classproperty
                def POSITIVE_3005(cls):
                    return cls(3005)
                
                @schemas.classproperty
                def POSITIVE_3006(cls):
                    return cls(3006)
                
                @schemas.classproperty
                def POSITIVE_3007(cls):
                    return cls(3007)
                
                @schemas.classproperty
                def POSITIVE_3008(cls):
                    return cls(3008)
                
                @schemas.classproperty
                def POSITIVE_3009(cls):
                    return cls(3009)
                
                @schemas.classproperty
                def POSITIVE_3010(cls):
                    return cls(3010)
                
                @schemas.classproperty
                def POSITIVE_3011(cls):
                    return cls(3011)
                
                @schemas.classproperty
                def POSITIVE_3012(cls):
                    return cls(3012)
                
                @schemas.classproperty
                def POSITIVE_3013(cls):
                    return cls(3013)
                
                @schemas.classproperty
                def POSITIVE_3014(cls):
                    return cls(3014)
                
                @schemas.classproperty
                def POSITIVE_3015(cls):
                    return cls(3015)
                
                @schemas.classproperty
                def POSITIVE_3016(cls):
                    return cls(3016)
                
                @schemas.classproperty
                def POSITIVE_3017(cls):
                    return cls(3017)
                
                @schemas.classproperty
                def POSITIVE_3018(cls):
                    return cls(3018)
                
                @schemas.classproperty
                def POSITIVE_3019(cls):
                    return cls(3019)
                
                @schemas.classproperty
                def POSITIVE_3020(cls):
                    return cls(3020)
                
                @schemas.classproperty
                def POSITIVE_3021(cls):
                    return cls(3021)
                
                @schemas.classproperty
                def POSITIVE_3022(cls):
                    return cls(3022)
                
                @schemas.classproperty
                def POSITIVE_3023(cls):
                    return cls(3023)
                
                @schemas.classproperty
                def POSITIVE_3024(cls):
                    return cls(3024)
                
                @schemas.classproperty
                def POSITIVE_3025(cls):
                    return cls(3025)
                
                @schemas.classproperty
                def POSITIVE_3026(cls):
                    return cls(3026)
                
                @schemas.classproperty
                def POSITIVE_3027(cls):
                    return cls(3027)
                
                @schemas.classproperty
                def POSITIVE_3028(cls):
                    return cls(3028)
                
                @schemas.classproperty
                def POSITIVE_9000(cls):
                    return cls(9000)
                
                @schemas.classproperty
                def POSITIVE_9001(cls):
                    return cls(9001)
                
                @schemas.classproperty
                def POSITIVE_9002(cls):
                    return cls(9002)
                
                @schemas.classproperty
                def POSITIVE_9003(cls):
                    return cls(9003)
                
                @schemas.classproperty
                def POSITIVE_9004(cls):
                    return cls(9004)
                
                @schemas.classproperty
                def POSITIVE_9005(cls):
                    return cls(9005)
                
                @schemas.classproperty
                def POSITIVE_9006(cls):
                    return cls(9006)
                
                @schemas.classproperty
                def POSITIVE_9007(cls):
                    return cls(9007)
                
                @schemas.classproperty
                def POSITIVE_9008(cls):
                    return cls(9008)
                
                @schemas.classproperty
                def POSITIVE_9009(cls):
                    return cls(9009)
                
                @schemas.classproperty
                def POSITIVE_9010(cls):
                    return cls(9010)
                
                @schemas.classproperty
                def POSITIVE_9011(cls):
                    return cls(9011)
                
                @schemas.classproperty
                def POSITIVE_9012(cls):
                    return cls(9012)
                
                @schemas.classproperty
                def POSITIVE_9013(cls):
                    return cls(9013)
                
                @schemas.classproperty
                def POSITIVE_9014(cls):
                    return cls(9014)
                
                @schemas.classproperty
                def POSITIVE_9015(cls):
                    return cls(9015)
                
                @schemas.classproperty
                def POSITIVE_9016(cls):
                    return cls(9016)
                
                @schemas.classproperty
                def POSITIVE_9017(cls):
                    return cls(9017)
                
                @schemas.classproperty
                def POSITIVE_9018(cls):
                    return cls(9018)
                
                @schemas.classproperty
                def POSITIVE_9019(cls):
                    return cls(9019)
                
                @schemas.classproperty
                def POSITIVE_9020(cls):
                    return cls(9020)
                
                @schemas.classproperty
                def POSITIVE_9021(cls):
                    return cls(9021)
                
                @schemas.classproperty
                def POSITIVE_9022(cls):
                    return cls(9022)
                
                @schemas.classproperty
                def POSITIVE_9023(cls):
                    return cls(9023)
                
                @schemas.classproperty
                def POSITIVE_9024(cls):
                    return cls(9024)
                
                @schemas.classproperty
                def POSITIVE_9025(cls):
                    return cls(9025)
                
                @schemas.classproperty
                def POSITIVE_9026(cls):
                    return cls(9026)
                
                @schemas.classproperty
                def POSITIVE_9027(cls):
                    return cls(9027)
                
                @schemas.classproperty
                def POSITIVE_9028(cls):
                    return cls(9028)
                
                @schemas.classproperty
                def POSITIVE_9029(cls):
                    return cls(9029)
                
                @schemas.classproperty
                def POSITIVE_9030(cls):
                    return cls(9030)
                
                @schemas.classproperty
                def POSITIVE_9031(cls):
                    return cls(9031)
                
                @schemas.classproperty
                def POSITIVE_9032(cls):
                    return cls(9032)
                
                @schemas.classproperty
                def POSITIVE_9033(cls):
                    return cls(9033)
                
                @schemas.classproperty
                def POSITIVE_9034(cls):
                    return cls(9034)
                
                @schemas.classproperty
                def POSITIVE_9035(cls):
                    return cls(9035)
                
                @schemas.classproperty
                def POSITIVE_9036(cls):
                    return cls(9036)
                
                @schemas.classproperty
                def POSITIVE_9037(cls):
                    return cls(9037)
                
                @schemas.classproperty
                def POSITIVE_9038(cls):
                    return cls(9038)
                
                @schemas.classproperty
                def POSITIVE_9039(cls):
                    return cls(9039)
                
                @schemas.classproperty
                def POSITIVE_9040(cls):
                    return cls(9040)
                
                @schemas.classproperty
                def POSITIVE_9041(cls):
                    return cls(9041)
                
                @schemas.classproperty
                def POSITIVE_9042(cls):
                    return cls(9042)
                
                @schemas.classproperty
                def POSITIVE_9043(cls):
                    return cls(9043)
                
                @schemas.classproperty
                def POSITIVE_9044(cls):
                    return cls(9044)
                
                @schemas.classproperty
                def POSITIVE_9045(cls):
                    return cls(9045)
                
                @schemas.classproperty
                def POSITIVE_9046(cls):
                    return cls(9046)
                
                @schemas.classproperty
                def POSITIVE_9047(cls):
                    return cls(9047)
                
                @schemas.classproperty
                def POSITIVE_9048(cls):
                    return cls(9048)
                
                @schemas.classproperty
                def POSITIVE_9049(cls):
                    return cls(9049)
                
                @schemas.classproperty
                def POSITIVE_9050(cls):
                    return cls(9050)
                
                @schemas.classproperty
                def POSITIVE_9051(cls):
                    return cls(9051)
                
                @schemas.classproperty
                def POSITIVE_9052(cls):
                    return cls(9052)
                
                @schemas.classproperty
                def POSITIVE_9053(cls):
                    return cls(9053)
                
                @schemas.classproperty
                def POSITIVE_9054(cls):
                    return cls(9054)
                
                @schemas.classproperty
                def POSITIVE_9055(cls):
                    return cls(9055)
                
                @schemas.classproperty
                def POSITIVE_9056(cls):
                    return cls(9056)
                
                @schemas.classproperty
                def POSITIVE_9057(cls):
                    return cls(9057)
                
                @schemas.classproperty
                def POSITIVE_9058(cls):
                    return cls(9058)
                
                @schemas.classproperty
                def POSITIVE_9059(cls):
                    return cls(9059)
            group_name = schemas.StrSchema
            group_id = schemas.IntSchema
            id = schemas.IntSchema
            ipaddr = schemas.StrSchema
            mapping_id = schemas.IntSchema
            notes = schemas.StrSchema
            object_id = schemas.IntSchema
            otp_device_id = schemas.IntSchema
            otp_device_name = schemas.StrSchema
            param = schemas.StrSchema
            policy_id = schemas.IntSchema
            policy_name = schemas.StrSchema
            policy_type = schemas.StrSchema
            privilege_id = schemas.IntSchema
            proxy_ip = schemas.StrSchema
            radius_config_id = schemas.IntSchema
            resolved_at = schemas.StrSchema
            resource_type_id = schemas.IntSchema
            risk_cookie_id = schemas.StrSchema
            risk_reasons = schemas.StrSchema
            risk_score = schemas.IntSchema
            role_id = schemas.IntSchema
            role_name = schemas.StrSchema
            service_directory_id = schemas.IntSchema
            solved = schemas.BoolSchema
            trusted_idp_id = schemas.IntSchema
            user_field_id = schemas.IntSchema
            user_id = schemas.IntSchema
            user_name = schemas.StrSchema
            __annotations__ = {
                "account_id": account_id,
                "actor_system": actor_system,
                "actor_user_id": actor_user_id,
                "actor_user_name": actor_user_name,
                "adc_id": adc_id,
                "app-name": app_name,
                "app_id": app_id,
                "assumed_by_superadmin_or_reseller": assumed_by_superadmin_or_reseller,
                "assuming_acting_user_id": assuming_acting_user_id,
                "certificate_id": certificate_id,
                "client_id": client_id,
                "created_at": created_at,
                "custom_message": custom_message,
                "directory_sync_run_id": directory_sync_run_id,
                "error_description": error_description,
                "event_type_id": event_type_id,
                "group-name": group_name,
                "group_id": group_id,
                "id": id,
                "ipaddr": ipaddr,
                "mapping_id": mapping_id,
                "notes": notes,
                "object_id": object_id,
                "otp_device_id": otp_device_id,
                "otp_device_name": otp_device_name,
                "param": param,
                "policy_id": policy_id,
                "policy_name": policy_name,
                "policy_type": policy_type,
                "privilege_id": privilege_id,
                "proxy_ip": proxy_ip,
                "radius_config_id": radius_config_id,
                "resolved_at": resolved_at,
                "resource_type_id": resource_type_id,
                "risk_cookie_id": risk_cookie_id,
                "risk_reasons": risk_reasons,
                "risk_score": risk_score,
                "role_id": role_id,
                "role_name": role_name,
                "service_directory_id": service_directory_id,
                "solved": solved,
                "trusted_idp_id": trusted_idp_id,
                "user_field_id": user_field_id,
                "user_id": user_id,
                "user_name": user_name,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["actor_system"]) -> MetaOapg.properties.actor_system: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["actor_user_id"]) -> MetaOapg.properties.actor_user_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["actor_user_name"]) -> MetaOapg.properties.actor_user_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["adc_id"]) -> MetaOapg.properties.adc_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["app-name"]) -> MetaOapg.properties.app_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["app_id"]) -> MetaOapg.properties.app_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["assumed_by_superadmin_or_reseller"]) -> MetaOapg.properties.assumed_by_superadmin_or_reseller: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["assuming_acting_user_id"]) -> MetaOapg.properties.assuming_acting_user_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["certificate_id"]) -> MetaOapg.properties.certificate_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["client_id"]) -> MetaOapg.properties.client_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_message"]) -> MetaOapg.properties.custom_message: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["directory_sync_run_id"]) -> MetaOapg.properties.directory_sync_run_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_description"]) -> MetaOapg.properties.error_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["event_type_id"]) -> MetaOapg.properties.event_type_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["group-name"]) -> MetaOapg.properties.group_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["group_id"]) -> MetaOapg.properties.group_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ipaddr"]) -> MetaOapg.properties.ipaddr: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mapping_id"]) -> MetaOapg.properties.mapping_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["notes"]) -> MetaOapg.properties.notes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["object_id"]) -> MetaOapg.properties.object_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["otp_device_id"]) -> MetaOapg.properties.otp_device_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["otp_device_name"]) -> MetaOapg.properties.otp_device_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["param"]) -> MetaOapg.properties.param: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["policy_id"]) -> MetaOapg.properties.policy_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["policy_name"]) -> MetaOapg.properties.policy_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["policy_type"]) -> MetaOapg.properties.policy_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["privilege_id"]) -> MetaOapg.properties.privilege_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["proxy_ip"]) -> MetaOapg.properties.proxy_ip: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["radius_config_id"]) -> MetaOapg.properties.radius_config_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["resolved_at"]) -> MetaOapg.properties.resolved_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["resource_type_id"]) -> MetaOapg.properties.resource_type_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["risk_cookie_id"]) -> MetaOapg.properties.risk_cookie_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["risk_reasons"]) -> MetaOapg.properties.risk_reasons: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["risk_score"]) -> MetaOapg.properties.risk_score: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["role_id"]) -> MetaOapg.properties.role_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["role_name"]) -> MetaOapg.properties.role_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["service_directory_id"]) -> MetaOapg.properties.service_directory_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["solved"]) -> MetaOapg.properties.solved: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trusted_idp_id"]) -> MetaOapg.properties.trusted_idp_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user_field_id"]) -> MetaOapg.properties.user_field_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user_id"]) -> MetaOapg.properties.user_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user_name"]) -> MetaOapg.properties.user_name: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["account_id", "actor_system", "actor_user_id", "actor_user_name", "adc_id", "app-name", "app_id", "assumed_by_superadmin_or_reseller", "assuming_acting_user_id", "certificate_id", "client_id", "created_at", "custom_message", "directory_sync_run_id", "error_description", "event_type_id", "group-name", "group_id", "id", "ipaddr", "mapping_id", "notes", "object_id", "otp_device_id", "otp_device_name", "param", "policy_id", "policy_name", "policy_type", "privilege_id", "proxy_ip", "radius_config_id", "resolved_at", "resource_type_id", "risk_cookie_id", "risk_reasons", "risk_score", "role_id", "role_name", "service_directory_id", "solved", "trusted_idp_id", "user_field_id", "user_id", "user_name", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_id"]) -> typing.Union[MetaOapg.properties.account_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["actor_system"]) -> typing.Union[MetaOapg.properties.actor_system, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["actor_user_id"]) -> typing.Union[MetaOapg.properties.actor_user_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["actor_user_name"]) -> typing.Union[MetaOapg.properties.actor_user_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["adc_id"]) -> typing.Union[MetaOapg.properties.adc_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["app-name"]) -> typing.Union[MetaOapg.properties.app_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["app_id"]) -> typing.Union[MetaOapg.properties.app_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["assumed_by_superadmin_or_reseller"]) -> typing.Union[MetaOapg.properties.assumed_by_superadmin_or_reseller, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["assuming_acting_user_id"]) -> typing.Union[MetaOapg.properties.assuming_acting_user_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["certificate_id"]) -> typing.Union[MetaOapg.properties.certificate_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["client_id"]) -> typing.Union[MetaOapg.properties.client_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_message"]) -> typing.Union[MetaOapg.properties.custom_message, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["directory_sync_run_id"]) -> typing.Union[MetaOapg.properties.directory_sync_run_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_description"]) -> typing.Union[MetaOapg.properties.error_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["event_type_id"]) -> typing.Union[MetaOapg.properties.event_type_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["group-name"]) -> typing.Union[MetaOapg.properties.group_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["group_id"]) -> typing.Union[MetaOapg.properties.group_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ipaddr"]) -> typing.Union[MetaOapg.properties.ipaddr, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mapping_id"]) -> typing.Union[MetaOapg.properties.mapping_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["notes"]) -> typing.Union[MetaOapg.properties.notes, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["object_id"]) -> typing.Union[MetaOapg.properties.object_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["otp_device_id"]) -> typing.Union[MetaOapg.properties.otp_device_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["otp_device_name"]) -> typing.Union[MetaOapg.properties.otp_device_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["param"]) -> typing.Union[MetaOapg.properties.param, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["policy_id"]) -> typing.Union[MetaOapg.properties.policy_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["policy_name"]) -> typing.Union[MetaOapg.properties.policy_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["policy_type"]) -> typing.Union[MetaOapg.properties.policy_type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["privilege_id"]) -> typing.Union[MetaOapg.properties.privilege_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["proxy_ip"]) -> typing.Union[MetaOapg.properties.proxy_ip, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["radius_config_id"]) -> typing.Union[MetaOapg.properties.radius_config_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["resolved_at"]) -> typing.Union[MetaOapg.properties.resolved_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["resource_type_id"]) -> typing.Union[MetaOapg.properties.resource_type_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["risk_cookie_id"]) -> typing.Union[MetaOapg.properties.risk_cookie_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["risk_reasons"]) -> typing.Union[MetaOapg.properties.risk_reasons, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["risk_score"]) -> typing.Union[MetaOapg.properties.risk_score, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["role_id"]) -> typing.Union[MetaOapg.properties.role_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["role_name"]) -> typing.Union[MetaOapg.properties.role_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["service_directory_id"]) -> typing.Union[MetaOapg.properties.service_directory_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["solved"]) -> typing.Union[MetaOapg.properties.solved, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trusted_idp_id"]) -> typing.Union[MetaOapg.properties.trusted_idp_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user_field_id"]) -> typing.Union[MetaOapg.properties.user_field_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user_id"]) -> typing.Union[MetaOapg.properties.user_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user_name"]) -> typing.Union[MetaOapg.properties.user_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["account_id", "actor_system", "actor_user_id", "actor_user_name", "adc_id", "app-name", "app_id", "assumed_by_superadmin_or_reseller", "assuming_acting_user_id", "certificate_id", "client_id", "created_at", "custom_message", "directory_sync_run_id", "error_description", "event_type_id", "group-name", "group_id", "id", "ipaddr", "mapping_id", "notes", "object_id", "otp_device_id", "otp_device_name", "param", "policy_id", "policy_name", "policy_type", "privilege_id", "proxy_ip", "radius_config_id", "resolved_at", "resource_type_id", "risk_cookie_id", "risk_reasons", "risk_score", "role_id", "role_name", "service_directory_id", "solved", "trusted_idp_id", "user_field_id", "user_id", "user_name", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        account_id: typing.Union[MetaOapg.properties.account_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        actor_system: typing.Union[MetaOapg.properties.actor_system, str, schemas.Unset] = schemas.unset,
        actor_user_id: typing.Union[MetaOapg.properties.actor_user_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        actor_user_name: typing.Union[MetaOapg.properties.actor_user_name, str, schemas.Unset] = schemas.unset,
        adc_id: typing.Union[MetaOapg.properties.adc_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        app_id: typing.Union[MetaOapg.properties.app_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        assumed_by_superadmin_or_reseller: typing.Union[MetaOapg.properties.assumed_by_superadmin_or_reseller, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        assuming_acting_user_id: typing.Union[MetaOapg.properties.assuming_acting_user_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        certificate_id: typing.Union[MetaOapg.properties.certificate_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        client_id: typing.Union[MetaOapg.properties.client_id, str, schemas.Unset] = schemas.unset,
        created_at: typing.Union[MetaOapg.properties.created_at, str, schemas.Unset] = schemas.unset,
        custom_message: typing.Union[MetaOapg.properties.custom_message, str, schemas.Unset] = schemas.unset,
        directory_sync_run_id: typing.Union[MetaOapg.properties.directory_sync_run_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        error_description: typing.Union[MetaOapg.properties.error_description, str, schemas.Unset] = schemas.unset,
        event_type_id: typing.Union[MetaOapg.properties.event_type_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        group_id: typing.Union[MetaOapg.properties.group_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        ipaddr: typing.Union[MetaOapg.properties.ipaddr, str, schemas.Unset] = schemas.unset,
        mapping_id: typing.Union[MetaOapg.properties.mapping_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        notes: typing.Union[MetaOapg.properties.notes, str, schemas.Unset] = schemas.unset,
        object_id: typing.Union[MetaOapg.properties.object_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        otp_device_id: typing.Union[MetaOapg.properties.otp_device_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        otp_device_name: typing.Union[MetaOapg.properties.otp_device_name, str, schemas.Unset] = schemas.unset,
        param: typing.Union[MetaOapg.properties.param, str, schemas.Unset] = schemas.unset,
        policy_id: typing.Union[MetaOapg.properties.policy_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        policy_name: typing.Union[MetaOapg.properties.policy_name, str, schemas.Unset] = schemas.unset,
        policy_type: typing.Union[MetaOapg.properties.policy_type, str, schemas.Unset] = schemas.unset,
        privilege_id: typing.Union[MetaOapg.properties.privilege_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        proxy_ip: typing.Union[MetaOapg.properties.proxy_ip, str, schemas.Unset] = schemas.unset,
        radius_config_id: typing.Union[MetaOapg.properties.radius_config_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        resolved_at: typing.Union[MetaOapg.properties.resolved_at, str, schemas.Unset] = schemas.unset,
        resource_type_id: typing.Union[MetaOapg.properties.resource_type_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        risk_cookie_id: typing.Union[MetaOapg.properties.risk_cookie_id, str, schemas.Unset] = schemas.unset,
        risk_reasons: typing.Union[MetaOapg.properties.risk_reasons, str, schemas.Unset] = schemas.unset,
        risk_score: typing.Union[MetaOapg.properties.risk_score, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        role_id: typing.Union[MetaOapg.properties.role_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        role_name: typing.Union[MetaOapg.properties.role_name, str, schemas.Unset] = schemas.unset,
        service_directory_id: typing.Union[MetaOapg.properties.service_directory_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        solved: typing.Union[MetaOapg.properties.solved, bool, schemas.Unset] = schemas.unset,
        trusted_idp_id: typing.Union[MetaOapg.properties.trusted_idp_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        user_field_id: typing.Union[MetaOapg.properties.user_field_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        user_id: typing.Union[MetaOapg.properties.user_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        user_name: typing.Union[MetaOapg.properties.user_name, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Event':
        return super().__new__(
            cls,
            *_args,
            account_id=account_id,
            actor_system=actor_system,
            actor_user_id=actor_user_id,
            actor_user_name=actor_user_name,
            adc_id=adc_id,
            app_id=app_id,
            assumed_by_superadmin_or_reseller=assumed_by_superadmin_or_reseller,
            assuming_acting_user_id=assuming_acting_user_id,
            certificate_id=certificate_id,
            client_id=client_id,
            created_at=created_at,
            custom_message=custom_message,
            directory_sync_run_id=directory_sync_run_id,
            error_description=error_description,
            event_type_id=event_type_id,
            group_id=group_id,
            id=id,
            ipaddr=ipaddr,
            mapping_id=mapping_id,
            notes=notes,
            object_id=object_id,
            otp_device_id=otp_device_id,
            otp_device_name=otp_device_name,
            param=param,
            policy_id=policy_id,
            policy_name=policy_name,
            policy_type=policy_type,
            privilege_id=privilege_id,
            proxy_ip=proxy_ip,
            radius_config_id=radius_config_id,
            resolved_at=resolved_at,
            resource_type_id=resource_type_id,
            risk_cookie_id=risk_cookie_id,
            risk_reasons=risk_reasons,
            risk_score=risk_score,
            role_id=role_id,
            role_name=role_name,
            service_directory_id=service_directory_id,
            solved=solved,
            trusted_idp_id=trusted_idp_id,
            user_field_id=user_field_id,
            user_id=user_id,
            user_name=user_name,
            _configuration=_configuration,
            **kwargs,
        )



from onelogin.paths.api_1_privileges_privilege_id_users.get import ApiForget
from onelogin.paths.api_1_privileges_privilege_id_users.post import ApiForpost


class Api1PrivilegesPrivilegeIdUsers(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from onelogin import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401

from onelogin.model.error import Error
from onelogin.model.user import User

from . import path

# Query params
LimitSchema = schemas.Int32Schema
PageSchema = schemas.IntSchema
CursorSchema = schemas.StrSchema
CreatedSinceSchema = schemas.StrSchema
CreatedUntilSchema = schemas.StrSchema
UpdatedSinceSchema = schemas.StrSchema
UpdatedUntilSchema = schemas.StrSchema
LastLoginSinceSchema = schemas.StrSchema
LastLoginUntilSchema = schemas.StrSchema
FirstnameSchema = schemas.StrSchema
LastnameSchema = schemas.StrSchema
EmailSchema = schemas.StrSchema
UsernameSchema = schemas.StrSchema
SamaccountnameSchema = schemas.StrSchema
DirectoryIdSchema = schemas.IntSchema
ExternalIdSchema = schemas.StrSchema
UserIdsSchema = schemas.StrSchema
CustomAttributesAttributeNameSchema = schemas.StrSchema


class FieldsSchema(
    schemas.EnumBase,
    schemas.StrSchema
):


    class MetaOapg:
        enum_value_to_name = {
            "apps": "APPS",
            "users": "USERS",
            "admins": "ADMINS",
        }
    
    @schemas.classproperty
    def APPS(cls):
        return cls("apps")
    
    @schemas.classproperty
    def USERS(cls):
        return cls("users")
    
    @schemas.classproperty
    def ADMINS(cls):
        return cls("admins")
AppIdSchema = schemas.IntSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'limit': typing.Union[LimitSchema, decimal.Decimal, int, ],
        'page': typing.Union[PageSchema, decimal.Decimal, int, ],
        'cursor': typing.Union[CursorSchema, str, ],
        'created_since': typing.Union[CreatedSinceSchema, str, ],
        'created_until': typing.Union[CreatedUntilSchema, str, ],
        'updated_since': typing.Union[UpdatedSinceSchema, str, ],
        'updated_until': typing.Union[UpdatedUntilSchema, str, ],
        'last_login_since': typing.Union[LastLoginSinceSchema, str, ],
        'last_login_until': typing.Union[LastLoginUntilSchema, str, ],
        'firstname': typing.Union[FirstnameSchema, str, ],
        'lastname': typing.Union[LastnameSchema, str, ],
        'email': typing.Union[EmailSchema, str, ],
        'username': typing.Union[UsernameSchema, str, ],
        'samaccountname': typing.Union[SamaccountnameSchema, str, ],
        'directory_id': typing.Union[DirectoryIdSchema, decimal.Decimal, int, ],
        'external_id': typing.Union[ExternalIdSchema, str, ],
        'user_ids': typing.Union[UserIdsSchema, str, ],
        'custom_attributes.{attribute_name}': typing.Union[CustomAttributesAttributeNameSchema, str, ],
        'fields': typing.Union[FieldsSchema, str, ],
        'app_id': typing.Union[AppIdSchema, decimal.Decimal, int, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_limit = api_client.QueryParameter(
    name="limit",
    style=api_client.ParameterStyle.FORM,
    schema=LimitSchema,
    explode=True,
)
request_query_page = api_client.QueryParameter(
    name="page",
    style=api_client.ParameterStyle.FORM,
    schema=PageSchema,
    explode=True,
)
request_query_cursor = api_client.QueryParameter(
    name="cursor",
    style=api_client.ParameterStyle.FORM,
    schema=CursorSchema,
    explode=True,
)
request_query_created_since = api_client.QueryParameter(
    name="created_since",
    style=api_client.ParameterStyle.FORM,
    schema=CreatedSinceSchema,
    explode=True,
)
request_query_created_until = api_client.QueryParameter(
    name="created_until",
    style=api_client.ParameterStyle.FORM,
    schema=CreatedUntilSchema,
    explode=True,
)
request_query_updated_since = api_client.QueryParameter(
    name="updated_since",
    style=api_client.ParameterStyle.FORM,
    schema=UpdatedSinceSchema,
    explode=True,
)
request_query_updated_until = api_client.QueryParameter(
    name="updated_until",
    style=api_client.ParameterStyle.FORM,
    schema=UpdatedUntilSchema,
    explode=True,
)
request_query_last_login_since = api_client.QueryParameter(
    name="last_login_since",
    style=api_client.ParameterStyle.FORM,
    schema=LastLoginSinceSchema,
    explode=True,
)
request_query_last_login_until = api_client.QueryParameter(
    name="last_login_until",
    style=api_client.ParameterStyle.FORM,
    schema=LastLoginUntilSchema,
    explode=True,
)
request_query_firstname = api_client.QueryParameter(
    name="firstname",
    style=api_client.ParameterStyle.FORM,
    schema=FirstnameSchema,
    explode=True,
)
request_query_lastname = api_client.QueryParameter(
    name="lastname",
    style=api_client.ParameterStyle.FORM,
    schema=LastnameSchema,
    explode=True,
)
request_query_email = api_client.QueryParameter(
    name="email",
    style=api_client.ParameterStyle.FORM,
    schema=EmailSchema,
    explode=True,
)
request_query_username = api_client.QueryParameter(
    name="username",
    style=api_client.ParameterStyle.FORM,
    schema=UsernameSchema,
    explode=True,
)
request_query_samaccountname = api_client.QueryParameter(
    name="samaccountname",
    style=api_client.ParameterStyle.FORM,
    schema=SamaccountnameSchema,
    explode=True,
)
request_query_directory_id = api_client.QueryParameter(
    name="directory_id",
    style=api_client.ParameterStyle.FORM,
    schema=DirectoryIdSchema,
    explode=True,
)
request_query_external_id = api_client.QueryParameter(
    name="external_id",
    style=api_client.ParameterStyle.FORM,
    schema=ExternalIdSchema,
    explode=True,
)
request_query_user_ids = api_client.QueryParameter(
    name="user_ids",
    style=api_client.ParameterStyle.FORM,
    schema=UserIdsSchema,
    explode=True,
)
request_query_custom_attributes_attribute_name = api_client.QueryParameter(
    name="custom_attributes.{attribute_name}",
    style=api_client.ParameterStyle.FORM,
    schema=CustomAttributesAttributeNameSchema,
    explode=True,
)
request_query_fields = api_client.QueryParameter(
    name="fields",
    style=api_client.ParameterStyle.FORM,
    schema=FieldsSchema,
    explode=True,
)
request_query_app_id = api_client.QueryParameter(
    name="app_id",
    style=api_client.ParameterStyle.FORM,
    schema=AppIdSchema,
    explode=True,
)
_auth = [
    'OAuth2',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.ListSchema
):


    class MetaOapg:
        
        @staticmethod
        def items() -> typing.Type['User']:
            return User

    def __new__(
        cls,
        _arg: typing.Union[typing.Tuple['User'], typing.List['User']],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            _arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> 'User':
        return super().__getitem__(i)


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
SchemaFor400ResponseBodyApplicationJson = Error


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor400ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor400ResponseBodyApplicationJson),
    },
)
SchemaFor401ResponseBodyApplicationJson = Error


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor401ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor401ResponseBodyApplicationJson),
    },
)
SchemaFor422ResponseBodyApplicationJson = Error


@dataclass
class ApiResponseFor422(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor422ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_422 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor422,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor422ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '401': _response_for_401,
    '422': _response_for_422,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _list_users2_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _list_users2_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _list_users2_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _list_users2_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        List Users
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_limit,
            request_query_page,
            request_query_cursor,
            request_query_created_since,
            request_query_created_until,
            request_query_updated_since,
            request_query_updated_until,
            request_query_last_login_since,
            request_query_last_login_until,
            request_query_firstname,
            request_query_lastname,
            request_query_email,
            request_query_username,
            request_query_samaccountname,
            request_query_directory_id,
            request_query_external_id,
            request_query_user_ids,
            request_query_custom_attributes_attribute_name,
            request_query_fields,
            request_query_app_id,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class ListUsers2(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def list_users2(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def list_users2(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def list_users2(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def list_users2(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._list_users2_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._list_users2_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


